@@ -1481,6 +1481,10 @@ namespace OpenRCT2
         STR_LOSS_PER_ITEM_SOLD = 1857,
         STR_MAINTENANCE_OPTIONS_TIP = 1395,
         STR_MAIN_COLOUR_SCHEME = 2971,
+        STR_MAKE_INVISIBLE = 7023,
+        STR_MAKE_INVISIBLE_TIP = 7024,
+        STR_MAKE_VISIBLE = 7025,
+        STR_MAKE_VISIBLE_TIP = 7026,
         STR_MAXIMUM_LENGTH_BEFORE_DEPARTING_TIP = 1214,
         STR_MAXIMUM_WAITING_TIME = 1212,
         STR_MAX_CARS_PER_TRAIN_TIP = 5923,
