@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -115,16 +115,17 @@ public:
     void StartNewDraw();
     void FinishDraw();
 
-    void Clear(RenderTarget& rt, uint8_t paletteIndex) override;
-    void FillRect(RenderTarget& rt, uint32_t colour, int32_t x, int32_t y, int32_t w, int32_t h) override;
+    void Clear(RenderTarget& rt, PaletteIndex paletteIndex) override;
+    void FillRect(
+        RenderTarget& rt, PaletteIndex paletteIndex, int32_t left, int32_t top, int32_t right, int32_t bottom,
+        bool crossHatch = false) override;
     void FilterRect(
         RenderTarget& rt, FilterPaletteID palette, int32_t left, int32_t top, int32_t right, int32_t bottom) override;
-    void DrawLine(RenderTarget& rt, uint32_t colour, const ScreenLine& line) override;
-    void DrawSprite(RenderTarget& rt, const ImageId imageId, int32_t x, int32_t y) override;
-    void DrawSpriteRawMasked(
-        RenderTarget& rt, int32_t x, int32_t y, const ImageId maskImage, const ImageId colourImage) override;
-    void DrawSpriteSolid(RenderTarget& rt, const ImageId image, int32_t x, int32_t y, uint8_t colour) override;
-    void DrawGlyph(RenderTarget& rt, const ImageId image, int32_t x, int32_t y, const PaletteMap& palette) override;
+    void DrawLine(RenderTarget& rt, PaletteIndex colour, const ScreenLine& line) override;
+    void DrawSprite(RenderTarget& rt, ImageId imageId, int32_t x, int32_t y) override;
+    void DrawSpriteRawMasked(RenderTarget& rt, int32_t x, int32_t y, ImageId maskImage, ImageId colourImage) override;
+    void DrawSpriteSolid(RenderTarget& rt, ImageId image, int32_t x, int32_t y, PaletteIndex colour) override;
+    void DrawGlyph(RenderTarget& rt, ImageId image, int32_t x, int32_t y, const PaletteMap& palette) override;
     void DrawTTFBitmap(
         RenderTarget& rt, TextDrawInfo* info, TTFSurface* surface, int32_t x, int32_t y, uint8_t hintingThreshold) override;
 
@@ -175,7 +176,7 @@ public:
                 uint32_t xPixelOffset = pixelOffset;
                 xPixelOffset += (static_cast<uint8_t>(patternX - patternStartXOffset)) % patternXSpace;
 
-                auto patternPixel = pattern[patternYPos * 2 + 1];
+                auto patternPixel = static_cast<PaletteIndex>(pattern[patternYPos * 2 + 1]);
                 for (; xPixelOffset < finalPixelOffset; xPixelOffset += patternXSpace)
                 {
                     int32_t pixelX = xPixelOffset % rt.width;
@@ -203,7 +204,7 @@ private:
     uint32_t _height = 0;
     uint32_t _pitch = 0;
     size_t _bitsSize = 0;
-    std::unique_ptr<uint8_t[]> _bits;
+    std::unique_ptr<PaletteIndex[]> _bits;
 
     RenderTarget _mainRT = {};
 
@@ -293,9 +294,9 @@ public:
         for (int32_t i = 0; i < 256; i++)
         {
             SDL_Color colour;
-            colour.r = palette[i].Red;
-            colour.g = palette[i].Green;
-            colour.b = palette[i].Blue;
+            colour.r = palette[i].red;
+            colour.g = palette[i].green;
+            colour.b = palette[i].blue;
             colour.a = i == 0 ? 0 : 255;
 
             Palette[i] = colour;
@@ -484,8 +485,8 @@ public:
         framebuffer.GetPixels(_mainRT);
 
         int32_t stride = _mainRT.LineStride();
-        uint8_t* to = _mainRT.bits + y * stride + x;
-        uint8_t* from = _mainRT.bits + (y - dy) * stride + x - dx;
+        PaletteIndex* to = _mainRT.bits + y * stride + x;
+        PaletteIndex* from = _mainRT.bits + (y - dy) * stride + x - dx;
 
         if (dy > 0)
         {
@@ -518,7 +519,7 @@ public:
         return _drawingContext.get();
     }
 
-    RenderTarget* GetDrawingPixelInfo() override
+    RenderTarget* getRT() override
     {
         return &_mainRT;
     }
@@ -533,11 +534,6 @@ public:
         _drawingContext->GetTextureCache()->InvalidateImage(image);
     }
 
-    RenderTarget* GetDPI()
-    {
-        return &_mainRT;
-    }
-
 private:
     static OpenGLVersion GetOpenGLVersion()
     {
@@ -556,10 +552,10 @@ private:
     {
         size_t newBitsSize = pitch * height;
 
-        auto newBits = std::make_unique<uint8_t[]>(newBitsSize);
+        auto newBits = std::make_unique<PaletteIndex[]>(newBitsSize);
         if (_bits == nullptr)
         {
-            std::fill_n(newBits.get(), newBitsSize, 0);
+            std::fill_n(newBits.get(), newBitsSize, PaletteIndex::transparent);
         }
         else
         {
@@ -569,8 +565,8 @@ private:
             }
             else
             {
-                uint8_t* src = _bits.get();
-                uint8_t* dst = newBits.get();
+                PaletteIndex* src = _bits.get();
+                PaletteIndex* dst = newBits.get();
 
                 uint32_t minWidth = std::min(_width, width);
                 uint32_t minHeight = std::min(_height, height);
@@ -579,7 +575,7 @@ private:
                     std::copy_n(src, minWidth, dst);
                     if (pitch - minWidth > 0)
                     {
-                        std::fill_n(dst + minWidth, pitch - minWidth, 0);
+                        std::fill_n(dst + minWidth, pitch - minWidth, PaletteIndex::transparent);
                     }
                     src += _pitch;
                     dst += pitch;
@@ -625,7 +621,7 @@ private:
     }
 };
 
-std::unique_ptr<IDrawingEngine> OpenRCT2::Ui::CreateOpenGLDrawingEngine(IUiContext& uiContext)
+std::unique_ptr<IDrawingEngine> Ui::CreateOpenGLDrawingEngine(IUiContext& uiContext)
 {
     return std::make_unique<OpenGLDrawingEngine>(uiContext);
 }
@@ -682,14 +678,15 @@ void OpenGLDrawingContext::FinishDraw()
     _inDraw = false;
 }
 
-void OpenGLDrawingContext::Clear(RenderTarget& rt, uint8_t paletteIndex)
+void OpenGLDrawingContext::Clear(RenderTarget& rt, PaletteIndex paletteIndex)
 {
     Guard::Assert(_inDraw == true);
 
     FillRect(rt, paletteIndex, rt.x, rt.y, rt.x + rt.width, rt.y + rt.height);
 }
 
-void OpenGLDrawingContext::FillRect(RenderTarget& rt, uint32_t colour, int32_t left, int32_t top, int32_t right, int32_t bottom)
+void OpenGLDrawingContext::FillRect(
+    RenderTarget& rt, PaletteIndex paletteIndex, int32_t left, int32_t top, int32_t right, int32_t bottom, bool crossHatch)
 {
     Guard::Assert(_inDraw == true);
 
@@ -708,22 +705,17 @@ void OpenGLDrawingContext::FillRect(RenderTarget& rt, uint32_t colour, int32_t l
     command.texMaskAtlas = 0;
     command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
     command.palettes = { 0, 0, 0 };
-    command.colour = colour & 0xFF;
+    command.colour = EnumValue(paletteIndex);
     command.bounds = { left, top, right + 1, bottom + 1 };
     command.flags = DrawRectCommand::FLAG_NO_TEXTURE;
     command.depth = _drawCount++;
     command.zoom = 1.0f;
 
-    if (colour & 0x1000000)
+    if (crossHatch)
     {
         // cross-pattern
         command.flags |= DrawRectCommand::FLAG_CROSS_HATCH;
     }
-    else if (colour & 0x2000000)
-    {
-        assert(false);
-        // Should be FilterRect
-    }
 }
 
 void OpenGLDrawingContext::FilterRect(
@@ -837,7 +829,7 @@ bool OpenGLDrawingContext::CohenSutherlandLineClip(ScreenLine& line, const Rende
     }
 }
 
-void OpenGLDrawingContext::DrawLine(RenderTarget& rt, uint32_t colour, const ScreenLine& line)
+void OpenGLDrawingContext::DrawLine(RenderTarget& rt, PaletteIndex colour, const ScreenLine& line)
 {
     Guard::Assert(_inDraw == true);
 
@@ -856,7 +848,7 @@ void OpenGLDrawingContext::DrawLine(RenderTarget& rt, uint32_t colour, const Scr
     const int32_t y2 = trimmedLine.GetY2() - rt.y + clip.GetTop();
 
     command.bounds = { x1, y1, x2, y2 };
-    command.colour = colour & 0xFF;
+    command.colour = static_cast<GLuint>(colour);
     command.depth = _drawCount++;
 }
 
@@ -878,7 +870,7 @@ void OpenGLDrawingContext::DrawSprite(RenderTarget& rt, const ImageId imageId, c
 
     if (rt.zoom_level > ZoomLevel{ 0 })
     {
-        if (g1Element->flags & G1_FLAG_HAS_ZOOM_SPRITE)
+        if (g1Element->flags.has(G1Flag::hasZoomSprite))
         {
             RenderTarget zoomedRT;
             zoomedRT.bits = rt.bits;
@@ -888,10 +880,10 @@ void OpenGLDrawingContext::DrawSprite(RenderTarget& rt, const ImageId imageId, c
             zoomedRT.width = rt.width;
             zoomedRT.pitch = rt.pitch;
             zoomedRT.zoom_level = rt.zoom_level - 1;
-            DrawSprite(zoomedRT, imageId.WithIndex(imageId.GetIndex() - g1Element->zoomed_offset), x >> 1, y >> 1);
+            DrawSprite(zoomedRT, imageId.WithIndex(imageId.GetIndex() - g1Element->zoomedOffset), x >> 1, y >> 1);
             return;
         }
-        if (g1Element->flags & G1_FLAG_NO_ZOOM_DRAW)
+        if (g1Element->flags.has(G1Flag::noZoomDraw))
         {
             return;
         }
@@ -899,8 +891,8 @@ void OpenGLDrawingContext::DrawSprite(RenderTarget& rt, const ImageId imageId, c
 
     auto texture = _textureCache->GetOrLoadImageTexture(imageId);
 
-    int32_t left = x + g1Element->x_offset;
-    int32_t top = y + g1Element->y_offset;
+    int32_t left = x + g1Element->xOffset;
+    int32_t top = y + g1Element->yOffset;
 
     int32_t xModifier = 0;
     int32_t yModifier = 0;
@@ -1015,8 +1007,8 @@ void OpenGLDrawingContext::DrawSpriteRawMasked(
     const auto textureMask = _textureCache->GetOrLoadImageTexture(maskImage);
     const auto textureColour = _textureCache->GetOrLoadImageTexture(colourImage);
 
-    int32_t drawOffsetX = g1ElementMask->x_offset;
-    int32_t drawOffsetY = g1ElementMask->y_offset;
+    int32_t drawOffsetX = g1ElementMask->xOffset;
+    int32_t drawOffsetY = g1ElementMask->yOffset;
     int32_t drawWidth = std::min(g1ElementMask->width, g1ElementColour->width);
     int32_t drawHeight = std::min(g1ElementMask->height, g1ElementColour->height);
 
@@ -1063,7 +1055,7 @@ void OpenGLDrawingContext::DrawSpriteRawMasked(
     command.zoom = zoom;
 }
 
-void OpenGLDrawingContext::DrawSpriteSolid(RenderTarget& rt, const ImageId image, int32_t x, int32_t y, uint8_t colour)
+void OpenGLDrawingContext::DrawSpriteSolid(RenderTarget& rt, const ImageId image, int32_t x, int32_t y, PaletteIndex colour)
 {
     Guard::Assert(_inDraw == true);
 
@@ -1075,8 +1067,8 @@ void OpenGLDrawingContext::DrawSpriteSolid(RenderTarget& rt, const ImageId image
 
     const auto texture = _textureCache->GetOrLoadImageTexture(image);
 
-    int32_t drawOffsetX = g1Element->x_offset;
-    int32_t drawOffsetY = g1Element->y_offset;
+    int32_t drawOffsetX = g1Element->xOffset;
+    int32_t drawOffsetY = g1Element->yOffset;
     int32_t drawWidth = static_cast<uint16_t>(g1Element->width);
     int32_t drawHeight = static_cast<uint16_t>(g1Element->height);
 
@@ -1109,7 +1101,7 @@ void OpenGLDrawingContext::DrawSpriteSolid(RenderTarget& rt, const ImageId image
     command.texMaskBounds = texture.coords;
     command.palettes = { 0, 0, 0 };
     command.flags = DrawRectCommand::FLAG_NO_TEXTURE | DrawRectCommand::FLAG_MASK;
-    command.colour = colour & 0xFF;
+    command.colour = static_cast<GLuint>(colour);
     command.bounds = { left, top, right, bottom };
     command.depth = _drawCount++;
     command.zoom = 1.0f;
@@ -1127,8 +1119,8 @@ void OpenGLDrawingContext::DrawGlyph(RenderTarget& rt, const ImageId image, int3
 
     const auto texture = _textureCache->GetOrLoadGlyphTexture(image, palette);
 
-    int32_t left = x + g1Element->x_offset;
-    int32_t top = y + g1Element->y_offset;
+    int32_t left = x + g1Element->xOffset;
+    int32_t top = y + g1Element->yOffset;
     int32_t right = left + static_cast<uint16_t>(g1Element->width);
     int32_t bottom = top + static_cast<uint16_t>(g1Element->height);
 
@@ -1229,7 +1221,7 @@ void OpenGLDrawingContext::DrawTTFBitmap(
             command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
             command.palettes = { 0, 0, 0 };
             command.flags = DrawRectCommand::FLAG_TTF_TEXT;
-            command.colour = info->palette[3];
+            command.colour = static_cast<GLuint>(info->palette.shadowOutline);
             command.bounds = b;
             command.depth = _drawCount++;
             command.zoom = 1.0f;
@@ -1245,7 +1237,7 @@ void OpenGLDrawingContext::DrawTTFBitmap(
         command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
         command.palettes = { 0, 0, 0 };
         command.flags = DrawRectCommand::FLAG_TTF_TEXT;
-        command.colour = info->palette[3];
+        command.colour = static_cast<GLuint>(info->palette.shadowOutline);
         command.bounds = { left + 1, top + 1, right + 1, bottom + 1 };
         command.depth = _drawCount++;
         command.zoom = 1.0f;
@@ -1259,7 +1251,7 @@ void OpenGLDrawingContext::DrawTTFBitmap(
     command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
     command.palettes = { 0, 0, 0 };
     command.flags = DrawRectCommand::FLAG_TTF_TEXT | (hintingThreshold << 8);
-    command.colour = info->palette[1];
+    command.colour = static_cast<GLuint>(info->palette.fill);
     command.bounds = { left, top, right, bottom };
     command.depth = _drawCount++;
     command.zoom = 1.0f;
@@ -1349,7 +1341,7 @@ ScreenRect OpenGLDrawingContext::CalculateClipping(const RenderTarget& rt) const
 {
     // mber: Calculating the screen coordinates by dividing the difference between pointers like this is a dirty hack.
     //       It's also quite slow. In future the drawing code needs to be refactored to avoid this somehow.
-    const RenderTarget* mainRT = _engine.GetDPI();
+    const RenderTarget* mainRT = _engine.getRT();
     const int32_t bytesPerRow = mainRT->LineStride();
     const int32_t bitsOffset = static_cast<int32_t>(rt.bits - mainRT->bits);
     #ifndef NDEBUG
