@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -19,7 +19,9 @@
 #include <openrct2/config/Config.h>
 #include <openrct2/core/Path.hpp>
 #include <openrct2/core/String.hpp>
+#include <openrct2/drawing/Drawing.h>
 #include <openrct2/interface/Window.h>
+#include <openrct2/localisation/Formatter.h>
 #include <openrct2/localisation/StringIds.h>
 #include <openrct2/platform/Platform.h>
 #include <openrct2/rct2/T6Exporter.h>
@@ -58,7 +60,7 @@ namespace OpenRCT2::Ui::FileBrowser
         return nullptr;
 #endif
 
-        auto hasFilePicker = OpenRCT2::GetContext()->GetUiContext().HasFilePicker();
+        auto hasFilePicker = GetContext()->GetUiContext().HasFilePicker();
         auto& config = Config::Get().general;
 
         // Open system file picker?
@@ -67,7 +69,7 @@ namespace OpenRCT2::Ui::FileBrowser
             const bool isSave = (action == LoadSaveAction::save);
             const auto defaultDirectory = GetDir(type);
 
-            const u8string path = OpenSystemFileBrowser(isSave, type, defaultDirectory, defaultPath);
+            const u8string path = OpenSystemFileBrowser(isSave, type, defaultDirectory, defaultPath, trackDesign);
             if (!path.empty())
             {
                 Select(path.c_str(), action, type, trackDesign);
@@ -172,7 +174,7 @@ namespace OpenRCT2::Ui::FileBrowser
             return env.GetDirectoryPath(DirBase::user);
     }
 
-    const char* GetFilterPatternByType(const LoadSaveType type, const bool isSave)
+    u8string GetFilterPatternByType(const LoadSaveType type, const bool isSave, const TrackDesign* trackDesign)
     {
         switch (type)
         {
@@ -186,7 +188,15 @@ namespace OpenRCT2::Ui::FileBrowser
                 return isSave ? "*.park" : "*.park;*.sc6;*.sc4";
 
             case LoadSaveType::track:
-                return isSave ? "*.td6" : "*.td6;*.td4";
+            {
+                if (!isSave)
+                    return "*.td6;*.td4;*.td7";
+
+                if (trackDesign == nullptr)
+                    return "*.td6";
+
+                return "*" + trackDesignGetExtension(trackDesign->version);
+            }
 
             case LoadSaveType::heightmap:
                 return "*.bmp;*.png";
@@ -195,12 +205,12 @@ namespace OpenRCT2::Ui::FileBrowser
                 Guard::Fail("Unsupported load/save directory type.");
         }
 
-        return nullptr;
+        return {};
     }
 
     u8string RemovePatternWildcard(u8string_view pattern)
     {
-        while (pattern.length() >= 1 && pattern.front() == '*')
+        while (!pattern.empty() && pattern.front() == '*')
         {
             pattern.remove_prefix(1);
         }
@@ -243,7 +253,7 @@ namespace OpenRCT2::Ui::FileBrowser
 
         // Closing this will cause a Ride window to pop up, so we have to do this to ensure that
         // no windows are open (besides the toolbars and LoadSave window).
-        auto* windowMgr = Ui::GetWindowManager();
+        auto* windowMgr = GetWindowManager();
         windowMgr->CloseByClass(WindowClass::rideConstruction);
         windowMgr->CloseAllExceptClass(WindowClass::loadsave);
 
@@ -410,9 +420,10 @@ namespace OpenRCT2::Ui::FileBrowser
                     }
                     case LoadSaveType::track:
                     {
+                        auto extension = trackDesignGetExtension(trackDesignPtr->version);
                         SetAndSaveConfigPath(Config::Get().general.lastSaveTrackDirectory, pathBuffer);
 
-                        const auto withExtension = Path::WithExtension(pathBuffer, ".td6");
+                        const auto withExtension = Path::WithExtension(pathBuffer, extension);
                         String::set(pathBuffer, sizeof(pathBuffer), withExtension.c_str());
 
                         RCT2::T6Exporter t6Export{ *trackDesignPtr };
@@ -466,28 +477,7 @@ namespace OpenRCT2::Ui::FileBrowser
         }
     }
 
-    static u8string GetDefaultExtensionByType(LoadSaveType type)
-    {
-        switch (type)
-        {
-            case LoadSaveType::park:
-                return u8".park";
-
-            case LoadSaveType::landscape:
-                return u8".park";
-
-            case LoadSaveType::scenario:
-                return u8".park";
-
-            case LoadSaveType::track:
-                return u8".td6";
-
-            default:
-                return {};
-        }
-    }
-
-    static Ui::FileDialogDesc::Filter GetFilterForType(LoadSaveType type, bool isSave)
+    static FileDialogDesc::Filter GetFilterForType(LoadSaveType type, bool isSave, const TrackDesign* trackDesign)
     {
         switch (type)
         {
@@ -501,7 +491,7 @@ namespace OpenRCT2::Ui::FileBrowser
                 return { LanguageGetString(STR_OPENRCT2_SCENARIO_FILE), GetFilterPatternByType(type, isSave) };
 
             case LoadSaveType::track:
-                return { LanguageGetString(STR_OPENRCT2_TRACK_DESIGN_FILE), GetFilterPatternByType(type, isSave) };
+                return { LanguageGetString(STR_OPENRCT2_TRACK_DESIGN_FILE), GetFilterPatternByType(type, isSave, trackDesign) };
 
             case LoadSaveType::heightmap:
                 return { LanguageGetString(STR_OPENRCT2_HEIGHTMAP_FILE), GetFilterPatternByType(type, isSave) };
@@ -512,7 +502,8 @@ namespace OpenRCT2::Ui::FileBrowser
         }
     }
 
-    u8string OpenSystemFileBrowser(bool isSave, LoadSaveType type, u8string defaultDirectory, u8string defaultPath)
+    u8string OpenSystemFileBrowser(
+        bool isSave, LoadSaveType type, u8string defaultDirectory, u8string defaultPath, const TrackDesign* trackDesign)
     {
         u8string path = defaultDirectory;
         if (isSave)
@@ -533,15 +524,14 @@ namespace OpenRCT2::Ui::FileBrowser
             }
         }
 
-        u8string extension = GetDefaultExtensionByType(type);
         StringId title = GetTitleStringId(type, isSave);
 
-        Ui::FileDialogDesc desc = {
+        FileDialogDesc desc = {
             .Type = isSave ? FileDialogType::Save : FileDialogType::Open,
             .Title = LanguageGetString(title),
             .InitialDirectory = defaultDirectory,
             .DefaultFilename = isSave ? path : u8string(),
-            .Filters = { GetFilterForType(type, isSave), { LanguageGetString(STR_ALL_FILES), "*" } },
+            .Filters = { GetFilterForType(type, isSave, trackDesign), { LanguageGetString(STR_ALL_FILES), "*" } },
         };
 
         return ContextOpenCommonFileDialog(desc);
