@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -62,14 +62,14 @@ namespace OpenRCT2::Ui
         void Close() override;
         void Hide() override;
         void Toggle();
-        void WriteLine(const std::string& s, FormatToken colourFormat) override;
+        void WriteLine(const std::string& input, FormatToken colourFormat) override;
 
         void Input(ConsoleInput input);
         void RefreshCaret(size_t position = 0);
         void Scroll(int32_t linesToScroll);
 
         void Update();
-        void Draw(DrawPixelInfo& dpi) const;
+        void Draw(Drawing::RenderTarget& rt) const;
 
     private:
         void ClearInput();
