@@ -77,7 +77,7 @@ namespace OpenRCT2::Ui::Windows
     void WindowInitScrollWidgets(WindowBase& w);
     void WindowUpdateScrollWidgets(WindowBase& w);
 
-    void WindowMovePosition(WindowBase& w, const ScreenCoordsXY& screenCoords);
+    void WindowMovePosition(WindowBase& w, const ScreenCoordsXY& deltaCoords);
     void WindowSetPosition(WindowBase& w, const ScreenCoordsXY& screenCoords);
     void WindowMoveAndSnap(WindowBase& w, ScreenCoordsXY newWindowCoords, int32_t snapProximity);
     void WindowRelocateWindows(int32_t width, int32_t height);
