@@ -897,7 +897,7 @@ namespace OpenRCT2::Ui::Windows
             }
 
             // Add window tabs
-            if (_info.Desc.Tabs.size() != 0)
+            if (!_info.Desc.Tabs.empty())
             {
                 widgetList[WIDX_CONTENT_PANEL].top = kTabBarHeight;
             }
@@ -919,7 +919,7 @@ namespace OpenRCT2::Ui::Windows
             // Add custom widgets
             auto totalWidgets = _info.Desc.Widgets.size();
             auto tabWidgetsOffset = totalWidgets;
-            if (_info.Desc.Tabs.size() != 0)
+            if (!_info.Desc.Tabs.empty())
             {
                 totalWidgets += _info.Desc.Tabs[page].Widgets.size();
             }
@@ -1271,7 +1271,7 @@ namespace OpenRCT2::Ui::Windows
                 auto& widget = w->widgets[widgetIndex];
 
                 auto lastSelectedIndex = customWidgetInfo->SelectedIndex;
-                if (customWidgetInfo->Items.size() == 0)
+                if (customWidgetInfo->Items.empty())
                 {
                     selectedIndex = -1;
                 }
