@@ -16,9 +16,10 @@
 #include <openrct2/Game.h>
 #include <openrct2/GameState.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/BannerRemoveAction.h>
-#include <openrct2/actions/BannerSetNameAction.h>
-#include <openrct2/actions/BannerSetStyleAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/scenery/BannerRemoveAction.h>
+#include <openrct2/actions/scenery/BannerSetNameAction.h>
+#include <openrct2/actions/scenery/BannerSetStyleAction.h>
 #include <openrct2/config/Config.h>
 #include <openrct2/drawing/TextColour.h>
 #include <openrct2/object/BannerSceneryEntry.h>
