@@ -18,8 +18,9 @@
 #include <openrct2/GameState.h>
 #include <openrct2/OpenRCT2.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/CheatSetAction.h>
-#include <openrct2/actions/ParkSetDateAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/cheats/CheatSetAction.h>
+#include <openrct2/actions/park/ParkSetDateAction.h>
 #include <openrct2/config/Config.h>
 #include <openrct2/core/EnumUtils.hpp>
 #include <openrct2/drawing/Drawing.h>
