@@ -16,7 +16,8 @@
 #include <openrct2/GameState.h>
 #include <openrct2/Input.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/ClearAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/terraform/ClearAction.h>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/ui/WindowManager.h>
