@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -16,6 +16,8 @@
 #include <openrct2/Input.h>
 #include <openrct2/OpenRCT2.h>
 #include <openrct2/SpriteIds.h>
+#include <openrct2/drawing/ColourMap.h>
+#include <openrct2/drawing/Drawing.h>
 #include <openrct2/drawing/Rectangle.h>
 #include <openrct2/interface/ColourWithFlags.h>
 #include <openrct2/interface/Cursors.h>
@@ -112,7 +114,7 @@ namespace OpenRCT2::Ui::Windows
         int16_t columnSplitOffset = width / 2;
 
         if (researchItem.type == Research::EntryType::ride
-            && !GetRideTypeDescriptor(researchItem.baseRideType).HasFlag(RtdFlag::listVehiclesSeparately))
+            && !GetRideTypeDescriptor(researchItem.baseRideType).flags.has(RtdFlag::listVehiclesSeparately))
         {
             const StringId rideTypeName = GetRideNaming(researchItem.baseRideType, GetRideEntryByIndex(researchItem.entryIndex))
                                               .Name;
@@ -274,7 +276,7 @@ namespace OpenRCT2::Ui::Windows
             const auto& gameState = getGameState();
 
             // Draw background
-            uint8_t paletteIndex = ColourMapA[colours[1].colour].mid_light;
+            auto paletteIndex = getColourMap(colours[1].colour).midLight;
             GfxClear(rt, paletteIndex);
 
             int16_t boxWidth = widgets[WIDX_RESEARCH_ORDER_SCROLL].width() - 1;
@@ -312,7 +314,7 @@ namespace OpenRCT2::Ui::Windows
 
                 // TODO: this parameter by itself produces very light text.
                 // It needs a {BLACK} token in the string to work properly.
-                ColourWithFlags colour = { COLOUR_BLACK };
+                ColourWithFlags colour = { Drawing::Colour::black };
                 FontStyle fontStyle = FontStyle::medium;
                 auto darkness = TextDarkness::regular;
 
@@ -378,7 +380,7 @@ namespace OpenRCT2::Ui::Windows
                 rt,
                 { windowPos + ScreenCoordsXY{ bkWidget.left + 1, bkWidget.top + 1 },
                   windowPos + ScreenCoordsXY{ bkWidget.right - 1, bkWidget.bottom - 1 } },
-                ColourMapA[colours[1].colour].darkest);
+                getColourMap(colours[1].colour).darkest);
 
             auto* researchItem = WindowEditorInventionsListDragGetItem();
             if (researchItem == nullptr || researchItem->IsNull())
@@ -400,13 +402,13 @@ namespace OpenRCT2::Ui::Windows
             const auto* object = ObjectEntryGetObject(objectEntryType, researchItem->entryIndex);
             if (object != nullptr)
             {
-                RenderTarget clipDPI;
+                RenderTarget clipRT;
                 screenPos = windowPos + ScreenCoordsXY{ bkWidget.left + 1, bkWidget.top + 1 };
                 const auto clipWidth = bkWidget.width() - 2;
-                const auto clipHeight = bkWidget.height() - 1;
-                if (ClipDrawPixelInfo(clipDPI, rt, screenPos, clipWidth, clipHeight))
+                const auto clipHeight = bkWidget.height() - 2;
+                if (ClipRenderTarget(clipRT, rt, screenPos, clipWidth, clipHeight))
                 {
-                    object->DrawPreview(clipDPI, clipWidth, clipHeight);
+                    object->DrawPreview(clipRT, clipWidth, clipHeight);
                 }
             }
 
@@ -419,7 +421,7 @@ namespace OpenRCT2::Ui::Windows
             auto ft = Formatter();
 
             if (researchItem->type == Research::EntryType::ride
-                && !GetRideTypeDescriptor(researchItem->baseRideType).HasFlag(RtdFlag::listVehiclesSeparately))
+                && !GetRideTypeDescriptor(researchItem->baseRideType).flags.has(RtdFlag::listVehiclesSeparately))
             {
                 drawString = STR_WINDOW_COLOUR_2_STRINGID_STRINGID;
                 StringId rideTypeName = GetRideNaming(researchItem->baseRideType, GetRideEntryByIndex(researchItem->entryIndex))
@@ -605,7 +607,7 @@ namespace OpenRCT2::Ui::Windows
         void onOpen() override
         {
             setWidgets(_inventionListDragWidgets);
-            colours[1] = COLOUR_WHITE;
+            colours[1] = Drawing::Colour::white;
         }
 
         CursorID onCursor(const WidgetIndex widx, const ScreenCoordsXY& screenCoords, const CursorID defaultCursor) override
@@ -661,7 +663,7 @@ namespace OpenRCT2::Ui::Windows
 
             DrawResearchItem(
                 rt, _draggedItem, width, screenCoords, STR_WINDOW_COLOUR_2_STRINGID,
-                { ColourWithFlags{ COLOUR_BLACK }.withFlag(ColourFlag::withOutline, true) });
+                { ColourWithFlags{ Drawing::Colour::black }.withFlag(ColourFlag::withOutline, true) });
         }
 
         void init(ResearchItem& researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
@@ -686,7 +688,7 @@ namespace OpenRCT2::Ui::Windows
     static void WindowEditorInventionsListDragOpen(
         ResearchItem* researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
     {
-        auto* windowMgr = Ui::GetWindowManager();
+        auto* windowMgr = GetWindowManager();
         windowMgr->CloseByClass(WindowClass::editorInventionListDrag);
         auto* wnd = windowMgr->Create<InventionDragWindow>(
             WindowClass::editorInventionListDrag, { 10, 14 },
