@@ -194,7 +194,8 @@ namespace OpenRCT2::Ui::Windows
                     if (guestRide != nullptr)
                     {
                         ft.Add<StringId>(
-                            guestRide->getRideTypeDescriptor().HasFlag(RtdFlag::describeAsInside) ? STR_IN_RIDE : STR_ON_RIDE);
+                            guestRide->getRideTypeDescriptor().flags.has(RtdFlag::describeAsInside) ? STR_IN_RIDE
+                                                                                                    : STR_ON_RIDE);
                         guestRide->formatNameTo(ft);
 
                         _selectedFilter = GuestFilterType::Guests;
