@@ -18,8 +18,9 @@
 #include <openrct2/Input.h>
 #include <openrct2/OpenRCT2.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/LandBuyRightsAction.h>
-#include <openrct2/actions/LandSetRightsAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/park/LandBuyRightsAction.h>
+#include <openrct2/actions/park/LandSetRightsAction.h>
 #include <openrct2/core/String.hpp>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/localisation/Formatter.h>
