@@ -15,8 +15,9 @@
 #include <openrct2/GameState.h>
 #include <openrct2/Input.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/PlayerKickAction.h>
-#include <openrct2/actions/PlayerSetGroupAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/network/PlayerKickAction.h>
+#include <openrct2/actions/network/PlayerSetGroupAction.h>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/network/Network.h>
