@@ -11,7 +11,8 @@
 #include <openrct2-ui/windows/Windows.h>
 #include <openrct2/Game.h>
 #include <openrct2/GameState.h>
-#include <openrct2/actions/RideDemolishAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/ride/RideDemolishAction.h>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/ui/WindowManager.h>
 #include <openrct2/windows/Intent.h>
