@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -14,7 +14,9 @@
 #include <openrct2/Game.h>
 #include <openrct2/GameState.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/ParkSetResearchFundingAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/park/ParkSetResearchFundingAction.h>
+#include <openrct2/drawing/Drawing.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/localisation/Localisation.Date.h>
 #include <openrct2/management/Finance.h>
@@ -383,7 +385,7 @@ namespace OpenRCT2::Ui::Windows
             else if (gameState.researchNextItem->type == Research::EntryType::ride)
             {
                 const auto& rtd = GetRideTypeDescriptor(gameState.researchNextItem->baseRideType);
-                if (rtd.HasFlag(RtdFlag::listVehiclesSeparately))
+                if (rtd.flags.has(RtdFlag::listVehiclesSeparately))
                 {
                     ft.Add<StringId>(gameState.researchNextItem->GetName());
                 }
@@ -443,7 +445,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 lastDevelopmentFormat = STR_RESEARCH_RIDE_LABEL;
                 const auto& rtd = GetRideTypeDescriptor(gameState.researchLastItem->baseRideType);
-                if (rtd.HasFlag(RtdFlag::listVehiclesSeparately))
+                if (rtd.flags.has(RtdFlag::listVehiclesSeparately))
                 {
                     ft.Add<StringId>(gameState.researchLastItem->GetName());
                 }
