@@ -16,10 +16,11 @@
 #include <openrct2/Game.h>
 #include <openrct2/GameState.h>
 #include <openrct2/SpriteIds.h>
-#include <openrct2/actions/LargeSceneryRemoveAction.h>
-#include <openrct2/actions/SignSetNameAction.h>
-#include <openrct2/actions/SignSetStyleAction.h>
-#include <openrct2/actions/WallRemoveAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/scenery/LargeSceneryRemoveAction.h>
+#include <openrct2/actions/scenery/SignSetNameAction.h>
+#include <openrct2/actions/scenery/SignSetStyleAction.h>
+#include <openrct2/actions/scenery/WallRemoveAction.h>
 #include <openrct2/config/Config.h>
 #include <openrct2/object/LargeSceneryEntry.h>
 #include <openrct2/object/ObjectEntryManager.h>
