@@ -11,7 +11,8 @@
 #include <openrct2-ui/windows/Windows.h>
 #include <openrct2/Game.h>
 #include <openrct2/GameState.h>
-#include <openrct2/actions/StaffFireAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/peep/StaffFireAction.h>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/entity/EntityRegistry.h>
 #include <openrct2/entity/Staff.h>
