@@ -28,9 +28,10 @@
 #include <openrct2/ParkImporter.h>
 #include <openrct2/SpriteIds.h>
 #include <openrct2/Version.h>
-#include <openrct2/actions/GameSetSpeedAction.h>
-#include <openrct2/actions/LoadOrQuitAction.h>
-#include <openrct2/actions/PauseToggleAction.h>
+#include <openrct2/actions/GameActionRunner.h>
+#include <openrct2/actions/general/GameSetSpeedAction.h>
+#include <openrct2/actions/general/LoadOrQuitAction.h>
+#include <openrct2/actions/general/PauseToggleAction.h>
 #include <openrct2/audio/Audio.h>
 #include <openrct2/config/Config.h>
 #include <openrct2/core/Numerics.hpp>
