@@ -17,12 +17,12 @@
 #include "OpenRCT2.h"
 #include "ParkImporter.h"
 #include "PlatformEnvironment.h"
-#include "actions/CheatSetAction.h"
-#include "actions/FootpathPlaceAction.h"
-#include "actions/GameAction.h"
-#include "actions/RideEntranceExitPlaceAction.h"
-#include "actions/TileModifyAction.h"
-#include "actions/TrackPlaceAction.h"
+#include "actions/GameActionRunner.h"
+#include "actions/cheats/CheatSetAction.h"
+#include "actions/footpath/FootpathPlaceAction.h"
+#include "actions/general/TileModifyAction.h"
+#include "actions/ride/RideEntranceExitPlaceAction.h"
+#include "actions/track/TrackPlaceAction.h"
 #include "config/Config.h"
 #include "core/Compression.h"
 #include "core/DataSerialiser.h"
