@@ -9,14 +9,17 @@
 
 #include "../core/Guard.hpp"
 #include "Drawing.h"
+#include "PaletteIndex.h"
+
+using OpenRCT2::Drawing::PaletteIndex;
 
 #ifdef __AVX2__
 
     #include <immintrin.h>
 
 void MaskAvx2(
-    int32_t width, int32_t height, const uint8_t* RESTRICT maskSrc, const uint8_t* RESTRICT colourSrc, uint8_t* RESTRICT dst,
-    int32_t maskWrap, int32_t colourWrap, int32_t dstWrap)
+    int32_t width, int32_t height, const uint8_t* RESTRICT maskSrc, const uint8_t* RESTRICT colourSrc,
+    PaletteIndex* RESTRICT dst, int32_t maskWrap, int32_t colourWrap, int32_t dstWrap)
 {
     if (width == 32)
     {
@@ -48,8 +51,8 @@ void MaskAvx2(
     #endif
 
 void MaskAvx2(
-    int32_t width, int32_t height, const uint8_t* RESTRICT maskSrc, const uint8_t* RESTRICT colourSrc, uint8_t* RESTRICT dst,
-    int32_t maskWrap, int32_t colourWrap, int32_t dstWrap)
+    int32_t width, int32_t height, const uint8_t* RESTRICT maskSrc, const uint8_t* RESTRICT colourSrc,
+    PaletteIndex* RESTRICT dst, int32_t maskWrap, int32_t colourWrap, int32_t dstWrap)
 {
     OpenRCT2::Guard::Fail("AVX2 function called on a CPU that doesn't support AVX2");
 }
