@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -11,9 +11,9 @@
 
 #include "../Diagnostic.h"
 #include "../OpenRCT2.h"
+#include "../SpriteIds.h"
 #include "../core/Console.hpp"
 #include "../core/Guard.hpp"
-#include "../sprites.h"
 #include "Drawing.h"
 
 #include <algorithm>
