@@ -159,7 +159,7 @@ bool Balloon::Collides() const
         {
             const TrackElement* trackElement = tileElement->AsTrack();
             const auto* ride = GetRide(trackElement->GetRideIndex());
-            if (ride != nullptr && ride->getRideTypeDescriptor().HasFlag(RtdFlag::hasRoofOverWholeRide))
+            if (ride != nullptr && ride->getRideTypeDescriptor().flags.has(RtdFlag::hasRoofOverWholeRide))
             {
                 check_ceiling = true;
             }
