@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -28,8 +28,6 @@ constexpr uint8_t kPeepMaxEnergyTarget = 255; // Oddly, this differs from max en
 
 constexpr auto kPeepClearanceHeight = 4 * kCoordsZStep;
 
-struct PaintSession;
-
 namespace OpenRCT2
 {
     class Formatter;
@@ -41,6 +39,11 @@ namespace OpenRCT2::GameActions
     class Result;
 }
 
+namespace OpenRCT2::Drawing
+{
+    enum class Colour : uint8_t;
+}
+
 enum class PeepState : uint8_t
 {
     falling = 0, // Drowning is part of falling
@@ -318,8 +321,8 @@ struct Peep : EntityBase
     };
     OpenRCT2::ObjectEntryIndex AnimationObjectIndex;
     PeepAnimationGroup AnimationGroup;
-    uint8_t TshirtColour;
-    uint8_t TrousersColour;
+    OpenRCT2::Drawing::Colour TshirtColour;
+    OpenRCT2::Drawing::Colour TrousersColour;
     union
     {
         uint16_t DestinationX;
@@ -416,20 +419,20 @@ public: // Peep
     [[nodiscard]] CoordsXY GetDestination() const;
 
     void Serialise(class DataSerialiser& stream);
-    void Paint(PaintSession& session, int32_t imageDirection) const;
 
     // TODO: Make these private again when done refactoring
 public: // Peep
     [[nodiscard]] bool CheckForPath();
-    bool ShouldWaitForLevelCrossing() const;
-    bool IsOnLevelCrossing() const;
-    bool IsOnPathBlockedByVehicle() const;
     std::pair<uint8_t, OpenRCT2::TileElement*> PerformNextAction();
     [[nodiscard]] int32_t GetZOnSlope(int32_t tile_x, int32_t tile_y);
     void SwitchNextAnimationType();
     [[nodiscard]] PeepAnimationType GetAnimationType();
 
 protected:
+    bool ShouldWaitForLevelCrossing() const;
+    bool IsOnLevelCrossing() const;
+    bool IsOnPathBlockedByVehicle() const;
+    void UpdateWaitingAtCrossing();
     void UpdateFalling();
     void Update1();
     void UpdatePicked();
@@ -460,7 +463,7 @@ void PeepWindowStateUpdate(Peep* peep);
 void PeepDecrementNumRiders(Peep* peep);
 
 void PeepSetMapTooltip(Peep* peep);
-int32_t PeepCompare(const EntityId sprite_index_a, const EntityId sprite_index_b);
+int32_t PeepCompare(EntityId sprite_index_a, EntityId sprite_index_b);
 
 void PeepUpdateNames();
 
