@@ -194,7 +194,7 @@ namespace OpenRCT2
 
     ObjectSourceGame Object::GetFirstSourceGame() const
     {
-        if (_sourceGames.size() == 0)
+        if (_sourceGames.empty())
             return ObjectSourceGame::custom;
 
         return _sourceGames[0];
@@ -423,7 +423,7 @@ namespace OpenRCT2
         {
             LOG_WARNING("%i fields found in version string '%s', expected X.Y.Z", nums.size(), version);
         }
-        if (nums.size() == 0)
+        if (nums.empty())
         {
             LOG_WARNING("No fields found in version string '%s', expected X.Y.Z", version);
             return std::make_tuple(0, 0, 0);
