@@ -27,6 +27,7 @@
 #include "../../world/TileInspector.h"
 #include "../../world/tile_element/WallElement.h"
 #include "Paint.TileElement.h"
+#include "Paint.Wall.h"
 
 using namespace OpenRCT2;
 using namespace OpenRCT2::Drawing;
@@ -175,21 +176,8 @@ static void PaintWallScrollingText(
                               : wallElement.GetSecondaryColour();
     auto textPaletteIndex = direction == 0 ? getColourMap(textColour).midDark : getColourMap(textColour).light;
 
-    auto ft = Formatter();
-    banner->formatTextTo(ft);
-    char signString[256];
-    if (Config::Get().general.upperCaseBanners)
-    {
-        FormatStringToUpper(signString, sizeof(signString), STR_SCROLLING_SIGN_TEXT, ft.Data());
-    }
-    else
-    {
-        FormatStringLegacy(signString, sizeof(signString), STR_SCROLLING_SIGN_TEXT, ft.Data());
-    }
-
-    auto stringWidth = GfxGetStringWidth(signString, FontStyle::tiny);
-    auto scroll = stringWidth > 0 ? (getGameState().currentTicks / 2) % stringWidth : 0;
-    auto imageId = ScrollingText::setup(session, STR_SCROLLING_SIGN_TEXT, ft, scroll, scrollingMode, textPaletteIndex);
+    auto bannerText = banner->getText();
+    auto imageId = ScrollingText::setup(session, bannerText, scrollingMode, textPaletteIndex);
     PaintAddImageAsChild(session, imageId, { 0, 0, height + 8 }, { boundsOffset, { 1, 1, 13 } });
 }
 
