@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -22,7 +22,7 @@ namespace OpenRCT2::Profiling
     static constexpr auto _profiling_func_name = func;                                                                         \
     struct Profiler_FunctionLiteral                                                                                            \
     {                                                                                                                          \
-        static constexpr const char* Str()                                                                                     \
+        static constexpr const char* str()                                                                                     \
         {                                                                                                                      \
             return _profiling_func_name;                                                                                       \
         }                                                                                                                      \
