@@ -12,8 +12,8 @@
 #include "../Context.h"
 #include "../Game.h"
 #include "../PlatformEnvironment.h"
-#include "../actions/FootpathPlaceAction.h"
 #include "../actions/GameActionResult.h"
+#include "../actions/footpath/FootpathPlaceAction.h"
 #include "../core/File.h"
 #include "../core/Guard.hpp"
 #include "../core/Json.hpp"
