@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -30,6 +30,7 @@
 #include <functional>
 
 using OpenRCT2::RCT12::TD46MazeElementType;
+using OpenRCT2::RCT12::TD46TrackElement;
 using OpenRCT2::SawyerCoding::SawyerChunkWriter;
 
 namespace OpenRCT2::RCT2
@@ -43,7 +44,7 @@ namespace OpenRCT2::RCT2
     {
         try
         {
-            auto fs = OpenRCT2::FileStream(path, OpenRCT2::FileMode::write);
+            auto fs = FileStream(path, FileMode::write);
             return SaveTrack(&fs);
         }
         catch (const std::exception& e)
@@ -53,20 +54,21 @@ namespace OpenRCT2::RCT2
         }
     }
 
-    bool T6Exporter::SaveTrack(OpenRCT2::IStream* stream)
+    bool T6Exporter::SaveTrack(IStream* stream)
     {
         auto& rtd = GetRideTypeDescriptor(_trackDesign.trackAndVehicle.rtdIndex);
         auto td6rideType = OpenRCT2RideTypeToRCT2RideType(_trackDesign.trackAndVehicle.rtdIndex);
-        OpenRCT2::MemoryStream tempStream;
+        MemoryStream tempStream;
         tempStream.WriteValue<uint8_t>(td6rideType);
         tempStream.WriteValue<uint8_t>(0);
         tempStream.WriteValue<uint32_t>(0);
         tempStream.WriteValue<uint8_t>(static_cast<uint8_t>(_trackDesign.operation.rideMode));
-        tempStream.WriteValue<uint8_t>(EnumValue(_trackDesign.appearance.vehicleColourSettings) | (2 << 2));
-        for (auto i = 0; i < RCT2::Limits::kMaxVehicleColours; i++)
+        tempStream.WriteValue<uint8_t>(
+            EnumValue(_trackDesign.appearance.vehicleColourSettings) | (EnumValue(_trackDesign.version) << 2));
+        for (auto i = 0; i < Limits::kMaxVehicleColours; i++)
         {
-            tempStream.WriteValue<uint8_t>(_trackDesign.appearance.vehicleColours[i].Body);
-            tempStream.WriteValue<uint8_t>(_trackDesign.appearance.vehicleColours[i].Trim);
+            tempStream.WriteValue<Drawing::Colour>(_trackDesign.appearance.vehicleColours[i].Body);
+            tempStream.WriteValue<Drawing::Colour>(_trackDesign.appearance.vehicleColours[i].Trim);
         }
         tempStream.WriteValue<uint8_t>(0);
         auto entranceStyle = GetStationStyleFromIdentifier(_trackDesign.appearance.stationObjectIdentifier);
@@ -106,23 +108,23 @@ namespace OpenRCT2::RCT2
         tempStream.WriteValue<money16>(ToMoney16(_trackDesign.statistics.upkeepCost));
         for (auto i = 0; i < Limits::kNumColourSchemes; i++)
         {
-            tempStream.WriteValue<uint8_t>(_trackDesign.appearance.trackColours[i].main);
+            tempStream.WriteValue<Drawing::Colour>(_trackDesign.appearance.trackColours[i].main);
         }
         for (auto i = 0; i < Limits::kNumColourSchemes; i++)
         {
-            tempStream.WriteValue<uint8_t>(_trackDesign.appearance.trackColours[i].additional);
+            tempStream.WriteValue<Drawing::Colour>(_trackDesign.appearance.trackColours[i].additional);
         }
         for (auto i = 0; i < Limits::kNumColourSchemes; i++)
         {
-            tempStream.WriteValue<uint8_t>(_trackDesign.appearance.trackColours[i].supports);
+            tempStream.WriteValue<Drawing::Colour>(_trackDesign.appearance.trackColours[i].supports);
         }
         tempStream.WriteValue<uint32_t>(0);
         tempStream.Write(&_trackDesign.trackAndVehicle.vehicleObject.Entry, sizeof(RCTObjectEntry));
         tempStream.WriteValue<uint8_t>(_trackDesign.statistics.spaceRequired.x);
         tempStream.WriteValue<uint8_t>(_trackDesign.statistics.spaceRequired.y);
-        for (auto i = 0; i < RCT2::Limits::kMaxVehicleColours; i++)
+        for (auto i = 0; i < Limits::kMaxVehicleColours; i++)
         {
-            tempStream.WriteValue<uint8_t>(_trackDesign.appearance.vehicleColours[i].Tertiary);
+            tempStream.WriteValue<Drawing::Colour>(_trackDesign.appearance.vehicleColours[i].Tertiary);
         }
         auto liftSpeed = std::min<uint8_t>(31, _trackDesign.operation.liftHillSpeed);
         auto numCircuits = std::min<uint8_t>(7, _trackDesign.operation.numCircuits);
@@ -130,60 +132,99 @@ namespace OpenRCT2::RCT2
 
         if (rtd.specialType == RtdSpecialType::maze)
         {
-            for (const auto& mazeElement : _trackDesign.mazeElements)
-            {
-                tempStream.WriteValue<int8_t>(mazeElement.location.x);
-                tempStream.WriteValue<int8_t>(mazeElement.location.y);
-                tempStream.WriteValue<uint16_t>(mazeElement.mazeEntry);
-            }
-
-            for (const auto& entranceElement : _trackDesign.entranceElements)
-            {
-                tempStream.WriteValue<int8_t>(entranceElement.location.x);
-                tempStream.WriteValue<int8_t>(entranceElement.location.y);
-                tempStream.WriteValue<int8_t>(entranceElement.location.direction);
-                tempStream.WriteValue<int8_t>(
-                    EnumValue(entranceElement.isExit ? TD46MazeElementType::exit : TD46MazeElementType::entrance));
-            }
-
-            tempStream.WriteValue<uint32_t>(0);
+            exportMazeElements(tempStream);
         }
         else
         {
-            for (const auto& trackElement : _trackDesign.trackElements)
-            {
-                auto trackType = OpenRCT2TrackTypeToRCT2(trackElement.type);
-                if (trackElement.type == TrackElemType::multiDimInvertedUp90ToFlatQuarterLoop)
-                {
-                    trackType = OpenRCT2::RCT12::TrackElemType::invertedUp90ToFlatQuarterLoopAlias;
-                }
-                tempStream.WriteValue<uint8_t>(static_cast<uint8_t>(trackType));
-                auto flags = RCT12::convertToTD46Flags(trackElement);
-                tempStream.WriteValue<uint8_t>(flags);
-            }
+            if (_trackDesign.version == RCT12::TD46Version::td7)
+                exportTrackElementsTD7(tempStream);
+            else
+                exportTrackElements(tempStream);
 
-            tempStream.WriteValue<uint8_t>(0xFF);
-
-            for (const auto& entranceElement : _trackDesign.entranceElements)
-            {
-                tempStream.WriteValue<uint8_t>(
-                    entranceElement.location.z == -1 ? static_cast<uint8_t>(0x80) : entranceElement.location.z);
-                tempStream.WriteValue<uint8_t>(entranceElement.location.direction | (entranceElement.isExit << 7));
-                auto xy = entranceElement.location.ToCoordsXY();
-                tempStream.WriteValue<int16_t>(xy.x);
-                tempStream.WriteValue<int16_t>(xy.y);
-            }
-
-            tempStream.WriteValue<uint8_t>(0xFF);
+            exportEntranceElements(tempStream);
         }
 
+        exportSceneryElements(tempStream);
+
+        SawyerChunkWriter sawyerCoding(stream);
+        sawyerCoding.WriteChunkTrack(tempStream.GetData(), tempStream.GetLength());
+        return true;
+    }
+
+    void T6Exporter::exportMazeElements(IStream& tempStream) const
+    {
+        for (const auto& mazeElement : _trackDesign.mazeElements)
+        {
+            tempStream.WriteValue<int8_t>(mazeElement.location.x);
+            tempStream.WriteValue<int8_t>(mazeElement.location.y);
+            tempStream.WriteValue<uint16_t>(mazeElement.mazeEntry);
+        }
+
+        for (const auto& entranceElement : _trackDesign.entranceElements)
+        {
+            tempStream.WriteValue<int8_t>(entranceElement.location.x);
+            tempStream.WriteValue<int8_t>(entranceElement.location.y);
+            tempStream.WriteValue<int8_t>(entranceElement.location.direction);
+            tempStream.WriteValue<int8_t>(
+                EnumValue(entranceElement.isExit ? TD46MazeElementType::exit : TD46MazeElementType::entrance));
+        }
+
+        tempStream.WriteValue<uint32_t>(0);
+    }
+
+    void T6Exporter::exportTrackElements(IStream& tempStream) const
+    {
+        for (const auto& trackElement : _trackDesign.trackElements)
+        {
+            auto trackType = OpenRCT2TrackTypeToRCT2(trackElement.type);
+            if (trackElement.type == TrackElemType::multiDimInvertedUp90ToFlatQuarterLoop)
+            {
+                trackType = RCT12::TrackElemType::invertedUp90ToFlatQuarterLoopAlias;
+            }
+            tempStream.WriteValue<uint8_t>(static_cast<uint8_t>(trackType));
+            auto flags = RCT12::convertToTD46Flags(trackElement, _trackDesign.version);
+            tempStream.WriteValue<uint8_t>(flags);
+        }
+
+        tempStream.WriteValue<uint8_t>(0xFF);
+    }
+
+    void T6Exporter::exportTrackElementsTD7(IStream& tempStream) const
+    {
+        for (const auto& trackElement : _trackDesign.trackElements)
+        {
+            auto flags = RCT12::convertToTD46Flags(trackElement, _trackDesign.version);
+            TD7TrackElement element = { trackElement.type, flags };
+            tempStream.WriteValue<TD7TrackElement>(element);
+        }
+
+        tempStream.WriteValue<uint16_t>(0xFFFF);
+    }
+
+    void T6Exporter::exportEntranceElements(IStream& tempStream) const
+    {
+        for (const auto& entranceElement : _trackDesign.entranceElements)
+        {
+            tempStream.WriteValue<uint8_t>(
+                entranceElement.location.z == -1 ? static_cast<uint8_t>(0x80) : entranceElement.location.z);
+            tempStream.WriteValue<uint8_t>(entranceElement.location.direction | (entranceElement.isExit << 7));
+            auto xy = entranceElement.location.ToCoordsXY();
+            tempStream.WriteValue<int16_t>(xy.x);
+            tempStream.WriteValue<int16_t>(xy.y);
+        }
+
+        tempStream.WriteValue<uint8_t>(0xFF);
+    }
+
+    void T6Exporter::exportSceneryElements(IStream& tempStream) const
+    {
         for (const auto& sceneryElement : _trackDesign.sceneryElements)
         {
             auto flags = sceneryElement.flags;
             if (sceneryElement.sceneryObject.Entry.GetType() == ObjectType::walls)
             {
                 flags &= ~0xFC;
-                flags |= (sceneryElement.tertiaryColour << 2);
+                flags |= (EnumValue(sceneryElement.tertiaryColour) << 2);
             }
 
             tempStream.Write(&sceneryElement.sceneryObject.Entry, sizeof(RCTObjectEntry));
@@ -192,14 +233,10 @@ namespace OpenRCT2::RCT2
             tempStream.WriteValue<int8_t>(tileCoords.y);
             tempStream.WriteValue<int8_t>(tileCoords.z);
             tempStream.WriteValue<uint8_t>(flags);
-            tempStream.WriteValue<uint8_t>(sceneryElement.primaryColour);
-            tempStream.WriteValue<uint8_t>(sceneryElement.secondaryColour);
+            tempStream.WriteValue<Drawing::Colour>(sceneryElement.primaryColour);
+            tempStream.WriteValue<Drawing::Colour>(sceneryElement.secondaryColour);
         }
 
         tempStream.WriteValue<uint8_t>(0xFF);
-
-        SawyerChunkWriter sawyerCoding(stream);
-        sawyerCoding.WriteChunkTrack(tempStream.GetData(), tempStream.GetLength());
-        return true;
     }
 } // namespace OpenRCT2::RCT2
