@@ -12,11 +12,12 @@
 #include "../Context.h"
 #include "../GameState.h"
 #include "../Input.h"
+#include "../actions/GameActionRunner.h"
 #include "../actions/ResultWithMessage.h"
-#include "../actions/RideEntranceExitRemoveAction.h"
-#include "../actions/RideSetSettingAction.h"
-#include "../actions/RideSetStatusAction.h"
-#include "../actions/TrackRemoveAction.h"
+#include "../actions/ride/RideEntranceExitRemoveAction.h"
+#include "../actions/ride/RideSetSettingAction.h"
+#include "../actions/ride/RideSetStatusAction.h"
+#include "../actions/track/TrackRemoveAction.h"
 #include "../entity/EntityList.h"
 #include "../entity/EntityRegistry.h"
 #include "../entity/Staff.h"
@@ -100,7 +101,7 @@ static int32_t ride_check_if_construction_allowed(Ride& ride)
         ContextShowError(STR_INVALID_RIDE_TYPE, STR_CANT_EDIT_INVALID_RIDE_TYPE, ft);
         return 0;
     }
-    if (ride.lifecycleFlags & RIDE_LIFECYCLE_BROKEN_DOWN)
+    if (ride.flags.has(RideFlag::brokenDown))
     {
         ride.formatNameTo(ft);
         ContextShowError(STR_CANT_START_CONSTRUCTION_ON, STR_HAS_BROKEN_DOWN_AND_REQUIRES_FIXING, ft);
@@ -153,9 +154,9 @@ void RideConstructionStart(Ride& ride)
  */
 static void ride_remove_cable_lift(Ride& ride)
 {
-    if (ride.lifecycleFlags & RIDE_LIFECYCLE_CABLE_LIFT)
+    if (ride.flags.has(RideFlag::cableLift))
     {
-        ride.lifecycleFlags &= ~RIDE_LIFECYCLE_CABLE_LIFT;
+        ride.flags.unset(RideFlag::cableLift);
         auto spriteIndex = ride.cableLift;
         do
         {
@@ -177,10 +178,9 @@ static void ride_remove_cable_lift(Ride& ride)
  */
 void Ride::removeVehicles()
 {
-    if (lifecycleFlags & RIDE_LIFECYCLE_ON_TRACK)
+    if (flags.has(RideFlag::onTrack))
     {
-        lifecycleFlags &= ~RIDE_LIFECYCLE_ON_TRACK;
-        lifecycleFlags &= ~(RIDE_LIFECYCLE_TEST_IN_PROGRESS | RIDE_LIFECYCLE_HAS_STALLED_VEHICLE);
+        flags.unset(RideFlag::onTrack, RideFlag::testInProgress, RideFlag::hasStalledVehicle);
 
         for (size_t i = 0; i <= Limits::kMaxTrainsPerRide; i++)
         {
@@ -223,7 +223,7 @@ void RideClearForConstruction(Ride& ride)
 {
     ride.measurement = {};
 
-    ride.lifecycleFlags &= ~(RIDE_LIFECYCLE_BREAKDOWN_PENDING | RIDE_LIFECYCLE_BROKEN_DOWN);
+    ride.flags.unset(RideFlag::breakdownPending, RideFlag::brokenDown);
     ride.windowInvalidateFlags.set(RideInvalidateFlag::main, RideInvalidateFlag::list);
 
     // Open circuit rides will go directly into building mode (creating ghosts) where it would normally clear the stats,
@@ -553,14 +553,14 @@ static void ride_construction_reset_current_piece()
 
     const auto& rtd = ride->getRideTypeDescriptor();
 
-    if (rtd.HasFlag(RtdFlag::hasTrack) || ride->numStations == 0)
+    if (rtd.flags.has(RtdFlag::hasTrack) || ride->numStations == 0)
     {
         _currentlySelectedTrack = rtd.StartTrackPiece;
         _currentTrackPitchEnd = TrackPitch::none;
         _currentTrackRollEnd = TrackRoll::none;
         _currentTrackHasLiftHill = false;
         _currentTrackAlternative.clearAll();
-        if (rtd.HasFlag(RtdFlag::startConstructionInverted))
+        if (rtd.flags.has(RtdFlag::startConstructionInverted))
         {
             _currentTrackAlternative.set(AlternativeTrackFlag::inverted);
         }
@@ -608,7 +608,7 @@ void RideConstructionSetDefaultNextPiece()
             tileElement = trackBeginEnd.begin_element;
             trackType = tileElement->AsTrack()->GetTrackType();
 
-            if (!ride->getRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
+            if (!ride->getRideTypeDescriptor().flags.has(RtdFlag::hasTrack))
             {
                 ride_construction_reset_current_piece();
                 return;
@@ -616,7 +616,7 @@ void RideConstructionSetDefaultNextPiece()
 
             // Set whether track is covered
             _currentTrackAlternative.unset(AlternativeTrackFlag::inverted);
-            if (rtd.HasFlag(RtdFlag::hasInvertedVariant))
+            if (rtd.flags.has(RtdFlag::hasInvertedVariant))
             {
                 if (tileElement->AsTrack()->IsInverted())
                 {
@@ -632,7 +632,7 @@ void RideConstructionSetDefaultNextPiece()
             _currentlySelectedTrack = ted->curveChain.next;
 
             // Set track banking
-            if (rtd.HasFlag(RtdFlag::hasInvertedVariant))
+            if (rtd.flags.has(RtdFlag::hasInvertedVariant))
             {
                 if (bank == TrackRoll::upsideDown)
                 {
@@ -675,7 +675,7 @@ void RideConstructionSetDefaultNextPiece()
 
             // Set whether track is covered
             _currentTrackAlternative.unset(AlternativeTrackFlag::inverted);
-            if (rtd.HasFlag(RtdFlag::hasInvertedVariant))
+            if (rtd.flags.has(RtdFlag::hasInvertedVariant))
             {
                 if (tileElement->AsTrack()->IsInverted())
                 {
@@ -691,7 +691,7 @@ void RideConstructionSetDefaultNextPiece()
             _currentlySelectedTrack = ted->curveChain.previous;
 
             // Set track banking
-            if (rtd.HasFlag(RtdFlag::hasInvertedVariant))
+            if (rtd.flags.has(RtdFlag::hasInvertedVariant))
             {
                 if (bank == TrackRoll::upsideDown)
                 {
@@ -972,7 +972,7 @@ bool RideModify(const CoordsXYE& input)
     if (rideEntry == nullptr || !ride_check_if_construction_allowed(*ride))
         return false;
 
-    if (ride->lifecycleFlags & RIDE_LIFECYCLE_INDESTRUCTIBLE && !getGameState().cheats.makeAllDestructible)
+    if (ride->flags.has(RideFlag::indestructible) && !getGameState().cheats.makeAllDestructible)
     {
         Formatter ft;
         ride->formatNameTo(ft);
@@ -995,7 +995,7 @@ bool RideModify(const CoordsXYE& input)
     if (tileElement.element->GetType() != TileElementType::Track)
         return false;
 
-    if (ride->getRideTypeDescriptor().HasFlag(RtdFlag::cannotHaveGaps))
+    if (ride->getRideTypeDescriptor().flags.has(RtdFlag::cannotHaveGaps))
     {
         CoordsXYE endOfTrackElement{};
         if (ride->findTrackGap(tileElement, &endOfTrackElement))
@@ -1027,7 +1027,7 @@ bool RideModify(const CoordsXYE& input)
     _rideConstructionNextArrowPulse = 0;
     gMapSelectFlags.unset(MapSelectFlag::enableArrow);
 
-    if (!ride->getRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
+    if (!ride->getRideTypeDescriptor().flags.has(RtdFlag::hasTrack))
     {
         WindowRideConstructionUpdateActiveElements();
         return true;
@@ -1088,7 +1088,7 @@ int32_t RideInitialiseConstructionWindow(Ride& ride)
     _currentTrackHasLiftHill = false;
     _currentTrackAlternative.clearAll();
 
-    if (ride.getRideTypeDescriptor().HasFlag(RtdFlag::startConstructionInverted))
+    if (ride.getRideTypeDescriptor().flags.has(RtdFlag::startConstructionInverted))
         _currentTrackAlternative.set(AlternativeTrackFlag::inverted);
 
     _previousTrackRollEnd = TrackRoll::none;
@@ -1242,7 +1242,7 @@ void Ride::validateStations()
 
                 // In the future this could look at the TED and see if the station has a sequence longer than 1
                 // tower ride, flat ride, shop
-                if (getRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation))
+                if (getRideTypeDescriptor().flags.has(RtdFlag::hasSinglePieceStation))
                 {
                     // if the track has multiple sequences, stop looking for the next one.
                     specialTrack = true;
@@ -1483,7 +1483,7 @@ bool RideSelectForwardsFromBack()
  */
 ResultWithMessage RideAreAllPossibleEntrancesAndExitsBuilt(const Ride& ride)
 {
-    if (ride.getRideTypeDescriptor().HasFlag(RtdFlag::isShopOrFacility))
+    if (ride.getRideTypeDescriptor().flags.has(RtdFlag::isShopOrFacility))
         return { true };
 
     for (auto& station : ride.getStations())
