@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -16,12 +16,11 @@
             __VA_ARGS__                                                                                                        \
         }                                                                                                                      \
     }
-#define kDefaultFlatRideColourPreset TRACK_COLOUR_PRESETS({ COLOUR_BRIGHT_RED, COLOUR_LIGHT_BLUE, COLOUR_YELLOW })
-#define kDefaultStallColourPreset TRACK_COLOUR_PRESETS({ COLOUR_BRIGHT_RED, COLOUR_BRIGHT_RED, COLOUR_BRIGHT_RED })
 
 #include "../audio/Audio.h"
 #include "../core/BitSet.hpp"
 #include "../core/EnumUtils.hpp"
+#include "../drawing/Colour.h"
 #include "../drawing/ImageIndexType.h"
 #include "../entity/Guest.h"
 #include "../localisation/StringIds.h"
@@ -47,6 +46,11 @@ constexpr uint8_t kDefaultInformationKioskHeight = 6 * kCoordsZStep;
 constexpr uint8_t kDefaultFirstAidHeight = 6 * kCoordsZStep;
 constexpr uint8_t kDefaultCashMachineHeight = 8 * kCoordsZStep;
 
+constexpr TrackColourPresetList kDefaultFlatRideColourPreset = TRACK_COLOUR_PRESETS(
+    { OpenRCT2::Drawing::Colour::brightRed, OpenRCT2::Drawing::Colour::lightBlue, OpenRCT2::Drawing::Colour::yellow });
+constexpr TrackColourPresetList kDefaultStallColourPreset = TRACK_COLOUR_PRESETS(
+    { OpenRCT2::Drawing::Colour::brightRed, OpenRCT2::Drawing::Colour::brightRed, OpenRCT2::Drawing::Colour::brightRed });
+
 struct RideComponentName
 {
     StringId singular;
@@ -235,12 +239,14 @@ struct RatingsModifier
     int32_t nausea;
 };
 
+constexpr int8_t kDynamicRideShelterRating = -1;
+
 struct RideRatingsDescriptor
 {
     RatingsCalculationType Type;
     OpenRCT2::RideRating::Tuple BaseRatings;
     uint8_t Unreliability;
-    // Used for rides with a set sheltered 8ths value (-1 = normal calculation)
+    // Used for rides with a set sheltered 8ths value (kDynamicRideShelterRating = normal calculation)
     int8_t RideShelter;
     bool RelaxRequirementsIfInversions;
     RatingsModifier Modifiers[32];
@@ -275,7 +281,7 @@ using StartRideMusicFunction = void (*)(const OpenRCT2::RideAudio::ViewportRideM
 using LightFXAddLightsMagicVehicleFunction = void (*)(const Vehicle* vehicle);
 using RideLocationFunction = CoordsXY (*)(const Vehicle& vehicle, const Ride& ride, const StationIndex& CurrentRideStation);
 using RideUpdateFunction = void (*)(Ride& ride);
-using RideUpdateMeasurementsSpecialElementsFunc = void (*)(Ride& ride, const OpenRCT2::TrackElemType trackType);
+using RideUpdateMeasurementsSpecialElementsFunc = void (*)(Ride& ride, OpenRCT2::TrackElemType trackType);
 using MusicTrackOffsetLengthFunc = std::pair<size_t, size_t> (*)(const Ride& ride);
 using SpecialElementRatingAdjustmentFunc = void (*)(const Ride& ride, int32_t& excitement, int32_t& intensity, int32_t& nausea);
 
@@ -300,7 +306,7 @@ struct TrackDrawerEntry
     StringId tooltip = kStringIdNone;
 
     void GetAvailableTrackGroups(RideTrackGroups& res) const;
-    bool SupportsTrackGroup(const TrackGroup trackGroup) const;
+    bool SupportsTrackGroup(TrackGroup trackGroup) const;
 };
 
 struct TrackDrawerDescriptor
@@ -439,7 +445,10 @@ enum class RtdFlag : uint8_t
     runningSpeedAffectsReliability,
     poweredLaunchAffectsReliability,
     reverseInclineLaunchAffectsReliability,
+
+    isDummyType,
 };
+using RtdFlags = FlagHolder<uint64_t, RtdFlag>;
 
 /**
  * Some rides are so different from others that they need some special code.
@@ -463,16 +472,24 @@ enum class RtdSpecialType
 };
 
 // Set on ride types that have a main colour, additional colour and support colour.
-constexpr uint64_t kRtdFlagsHasThreeColours = EnumsToFlags(
-    RtdFlag::hasTrackColourMain, RtdFlag::hasTrackColourAdditional, RtdFlag::hasTrackColourSupports);
+constexpr RtdFlags kRtdFlagsHasThreeColours = { RtdFlag::hasTrackColourMain, RtdFlag::hasTrackColourAdditional,
+                                                RtdFlag::hasTrackColourSupports };
 // Set on _all_ roller coaster ride types, including the _ALT types used for constructing upside down.
-constexpr uint64_t kRtdFlagsCommonCoaster = EnumsToFlags(
-    RtdFlag::hasGForces, RtdFlag::hasDataLogging, RtdFlag::hasDrops, RtdFlag::hasLoadOptions, RtdFlag::guestsWillRideAgain,
-    RtdFlag::hasVehicleColours, RtdFlag::checkForStalling, RtdFlag::hasTrack, RtdFlag::supportsMultipleColourSchemes,
-    RtdFlag::allowMusic, RtdFlag::interestingToLookAt, RtdFlag::canSynchroniseWithAdjacentStations);
+constexpr RtdFlags kRtdFlagsCommonCoaster = { RtdFlag::hasGForces,
+                                              RtdFlag::hasDataLogging,
+                                              RtdFlag::hasDrops,
+                                              RtdFlag::hasLoadOptions,
+                                              RtdFlag::guestsWillRideAgain,
+                                              RtdFlag::hasVehicleColours,
+                                              RtdFlag::checkForStalling,
+                                              RtdFlag::hasTrack,
+                                              RtdFlag::supportsMultipleColourSchemes,
+                                              RtdFlag::allowMusic,
+                                              RtdFlag::interestingToLookAt,
+                                              RtdFlag::canSynchroniseWithAdjacentStations };
 // Set on all roller coaster ride types, excluding the _ALT types used for constructing upside down.
-constexpr uint64_t kRtdFlagsCommonCoasterNonAlt = EnumsToFlags(
-    RtdFlag::showInTrackDesigner, RtdFlag::hasAirTime, RtdFlag::hasEntranceAndExit);
+constexpr RtdFlags kRtdFlagsCommonCoasterNonAlt = { RtdFlag::showInTrackDesigner, RtdFlag::hasAirTime,
+                                                    RtdFlag::hasEntranceAndExit };
 
 struct RideTypeDescriptor
 {
@@ -481,7 +498,7 @@ struct RideTypeDescriptor
     OpenRCT2::TrackElemType StartTrackPiece{};
     TrackDrawerDescriptor TrackPaintFunctions{};
     TrackDrawerDescriptor InvertedTrackPaintFunctions{};
-    uint64_t Flags{};
+    RtdFlags flags{};
     /** rct2: 0x0097C8AC */
     uint64_t RideModes{};
     RideMode DefaultMode{};
@@ -543,9 +560,8 @@ struct RideTypeDescriptor
     UpdateRideApproachVehicleWaypointsFunction UpdateRideApproachVehicleWaypoints = UpdateRideApproachVehicleWaypointsDefault;
     RtdSpecialType specialType = RtdSpecialType::none;
 
-    bool HasFlag(RtdFlag flag) const;
     /** @deprecated */
-    bool SupportsTrackGroup(const TrackGroup trackGroup) const;
+    bool SupportsTrackGroup(TrackGroup trackGroup) const;
     ResearchCategory GetResearchCategory() const;
     bool SupportsRideMode(RideMode rideMode) const;
     /**
@@ -621,7 +637,7 @@ constexpr RideTypeDescriptor kDummyRTD =
     .StartTrackPiece = OpenRCT2::TrackElemType::endStation,
     .TrackPaintFunctions = {},
     .InvertedTrackPaintFunctions = {},
-    .Flags = 0,
+    .flags = { RtdFlag::isDummyType },
     .RideModes = EnumsToFlags(RideMode::continuousCircuit),
     .DefaultMode = RideMode::continuousCircuit,
     .OperatingSettings = {},
