@@ -55,10 +55,10 @@ constexpr ShopItemDescriptor ShopItems[EnumValue(ShopItem::count)] = {
     /* ShopItem::lemonade */         {  0.40_GBP, 1.10_GBP,   2.10_GBP,  1.00_GBP,   1.20_GBP,      SPR_SHOP_ITEM_LEMONADE,            { STR_SHOP_ITEM_PRICE_LABEL_LEMONADE,               STR_SHOP_ITEM_SINGULAR_LEMONADE,            STR_SHOP_ITEM_PLURAL_LEMONADE,              STR_SHOP_ITEM_INDEFINITE_LEMONADE,              STR_SHOP_ITEM_DISPLAY_LEMONADE            }, SHOP_ITEM_FLAG_IS_DRINK,                                     Litter::Type::emptyBottle,      115,              ShopItem::emptyBottle,      PeepThoughtType::LemonadeMuch,          PeepThoughtType::Lemonade           },
     /* ShopItem::emptyBox */         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      SPR_SHOP_ITEM_EMPTY_BOX,           { STR_SHOP_ITEM_PRICE_LABEL_EMPTY_BOX,              STR_SHOP_ITEM_SINGULAR_EMPTY_BOX,           STR_SHOP_ITEM_PLURAL_EMPTY_BOX,             STR_SHOP_ITEM_INDEFINITE_EMPTY_BOX,             STR_SHOP_ITEM_DISPLAY_EMPTY_BOX           }, SHOP_ITEM_FLAG_IS_CONTAINER,                                 Litter::Type::emptyBox,         0,                ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
     /* ShopItem::emptyBottle */      {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      SPR_SHOP_ITEM_EMPTY_BOTTLE,        { STR_SHOP_ITEM_PRICE_LABEL_EMPTY_BOTTLE,           STR_SHOP_ITEM_SINGULAR_EMPTY_BOTTLE,        STR_SHOP_ITEM_PLURAL_EMPTY_BOTTLE,          STR_SHOP_ITEM_INDEFINITE_EMPTY_BOTTLE,          STR_SHOP_ITEM_DISPLAY_EMPTY_BOTTLE        }, SHOP_ITEM_FLAG_IS_CONTAINER,                                 Litter::Type::emptyBottle,      0,                ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
-    /* 28 */                         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                         kStringIdNone,                                   kStringIdNone,                                   kStringIdNone,                                       kStringIdNone                                  }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
-    /* 29 */                         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                         kStringIdNone,                                   kStringIdNone,                                   kStringIdNone,                                       kStringIdNone                                  }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
-    /* 30 */                         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                         kStringIdNone,                                   kStringIdNone,                                   kStringIdNone,                                       kStringIdNone                                  }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
-    /* ShopItem::admission */        {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                         kStringIdNone,                                   kStringIdNone,                                   kStringIdNone,                                       kStringIdNone                                  }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
+    /* 28 */                         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                    kStringIdNone,                              kStringIdNone,                              kStringIdNone,                                  kStringIdNone                             }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
+    /* 29 */                         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                    kStringIdNone,                              kStringIdNone,                              kStringIdNone,                                  kStringIdNone                             }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
+    /* 30 */                         {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                    kStringIdNone,                              kStringIdNone,                              kStringIdNone,                                  kStringIdNone                             }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
+    /* ShopItem::admission */        {  0.00_GBP, 0.00_GBP,   0.00_GBP,  0.00_GBP,   0.00_GBP,      0,                                 { kStringIdNone,                                    kStringIdNone,                              kStringIdNone,                              kStringIdNone,                                  kStringIdNone                             }, 0,                                                           Litter::Type::vomit,            0xFF,             ShopItem::none,             PeepThoughtType::None,                  PeepThoughtType::None               },
     /* ShopItem::photo2 */           {  0.20_GBP, 3.00_GBP,   3.00_GBP,  3.00_GBP,   0.00_GBP,      SPR_SHOP_ITEM_PHOTO2,              { STR_SHOP_ITEM_PRICE_LABEL_ON_RIDE_PHOTO,          STR_SHOP_ITEM_SINGULAR_ON_RIDE_PHOTO,       STR_SHOP_ITEM_PLURAL_ON_RIDE_PHOTO,         STR_SHOP_ITEM_INDEFINITE_ON_RIDE_PHOTO,         STR_SHOP_ITEM_DISPLAY_ON_RIDE_PHOTO       }, SHOP_ITEM_FLAG_IS_PHOTO | SHOP_ITEM_FLAG_IS_SOUVENIR,        Litter::Type::rubbish,          0,                ShopItem::none,             PeepThoughtType::Photo2Much,            PeepThoughtType::Photo2             },
     /* ShopItem::photo3 */           {  0.20_GBP, 3.00_GBP,   3.00_GBP,  3.00_GBP,   0.00_GBP,      SPR_SHOP_ITEM_PHOTO3,              { STR_SHOP_ITEM_PRICE_LABEL_ON_RIDE_PHOTO,          STR_SHOP_ITEM_SINGULAR_ON_RIDE_PHOTO,       STR_SHOP_ITEM_PLURAL_ON_RIDE_PHOTO,         STR_SHOP_ITEM_INDEFINITE_ON_RIDE_PHOTO,         STR_SHOP_ITEM_DISPLAY_ON_RIDE_PHOTO       }, SHOP_ITEM_FLAG_IS_PHOTO | SHOP_ITEM_FLAG_IS_SOUVENIR,        Litter::Type::rubbish,          0,                ShopItem::none,             PeepThoughtType::Photo3Much,            PeepThoughtType::Photo3             },
     /* ShopItem::photo4 */           {  0.20_GBP, 3.00_GBP,   3.00_GBP,  3.00_GBP,   0.00_GBP,      SPR_SHOP_ITEM_PHOTO4,              { STR_SHOP_ITEM_PRICE_LABEL_ON_RIDE_PHOTO,          STR_SHOP_ITEM_SINGULAR_ON_RIDE_PHOTO,       STR_SHOP_ITEM_PLURAL_ON_RIDE_PHOTO,         STR_SHOP_ITEM_INDEFINITE_ON_RIDE_PHOTO,         STR_SHOP_ITEM_DISPLAY_ON_RIDE_PHOTO       }, SHOP_ITEM_FLAG_IS_PHOTO | SHOP_ITEM_FLAG_IS_SOUVENIR,        Litter::Type::rubbish,          0,                ShopItem::none,             PeepThoughtType::Photo4Much,            PeepThoughtType::Photo4             },
@@ -136,7 +136,7 @@ money64 ShopItemGetCommonPrice(Ride* forRide, const ShopItem shopItem)
             {
                 return ride.price[1];
             }
-            if (GetShopItemDescriptor(shopItem).IsPhoto() && (ride.lifecycleFlags & RIDE_LIFECYCLE_ON_RIDE_PHOTO))
+            if (GetShopItemDescriptor(shopItem).IsPhoto() && ride.flags.has(RideFlag::onRidePhoto))
             {
                 return ride.price[1];
             }
