@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -16,20 +16,22 @@
 #include "../GameState.h"
 #include "../OpenRCT2.h"
 #include "../TrackImporter.h"
-#include "../actions/FootpathLayoutPlaceAction.h"
-#include "../actions/FootpathRemoveAction.h"
-#include "../actions/LargeSceneryPlaceAction.h"
-#include "../actions/LargeSceneryRemoveAction.h"
-#include "../actions/MazePlaceTrackAction.h"
-#include "../actions/RideCreateAction.h"
-#include "../actions/RideDemolishAction.h"
-#include "../actions/RideEntranceExitPlaceAction.h"
-#include "../actions/SmallSceneryPlaceAction.h"
-#include "../actions/SmallSceneryRemoveAction.h"
-#include "../actions/TrackPlaceAction.h"
-#include "../actions/TrackRemoveAction.h"
-#include "../actions/WallPlaceAction.h"
-#include "../actions/WallRemoveAction.h"
+#include "../actions/GameActionRunner.h"
+#include "../actions/ResultWithMessage.h"
+#include "../actions/footpath/FootpathLayoutPlaceAction.h"
+#include "../actions/footpath/FootpathRemoveAction.h"
+#include "../actions/ride/MazePlaceTrackAction.h"
+#include "../actions/ride/RideCreateAction.h"
+#include "../actions/ride/RideDemolishAction.h"
+#include "../actions/ride/RideEntranceExitPlaceAction.h"
+#include "../actions/scenery/LargeSceneryPlaceAction.h"
+#include "../actions/scenery/LargeSceneryRemoveAction.h"
+#include "../actions/scenery/SmallSceneryPlaceAction.h"
+#include "../actions/scenery/SmallSceneryRemoveAction.h"
+#include "../actions/scenery/WallPlaceAction.h"
+#include "../actions/scenery/WallRemoveAction.h"
+#include "../actions/track/TrackPlaceAction.h"
+#include "../actions/track/TrackRemoveAction.h"
 #include "../audio/Audio.h"
 #include "../config/Config.h"
 #include "../core/DataSerialiser.h"
@@ -52,6 +54,7 @@
 #include "../object/ObjectRepository.h"
 #include "../object/SmallSceneryEntry.h"
 #include "../object/StationObject.h"
+#include "../rct12/TD46.h"
 #include "../rct2/RCT2.h"
 #include "../ride/RideConstruction.h"
 #include "../sawyer_coding/SawyerCoding.h"
@@ -191,8 +194,6 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
         return { false, STR_TRACK_TOO_LARGE_OR_TOO_MUCH_SCENERY };
     }
 
-    StringId warningMessage = kStringIdNone;
-
     RideGetStartOfTrack(&trackElement);
 
     int32_t z = trackElement.element->GetBaseZ();
@@ -224,10 +225,9 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
     {
         const auto& element = trackElement.element->AsTrack();
 
-        // Remove this check for new track design format
         if (element->GetTrackType() > TrackElemType::highestAlias)
         {
-            return { false, STR_TRACK_ELEM_UNSUPPORTED_TD6 };
+            version = RCT12::TD46Version::td7;
         }
 
         TrackDesignTrackElement track{};
@@ -237,18 +237,17 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
         track.brakeBoosterSpeed = element->GetBrakeBoosterSpeed();
         track.seatRotation = element->GetSeatRotation();
 
-        // This warning will not apply to new track design format
         if (track.type == TrackElemType::blockBrakes && element->GetBrakeBoosterSpeed() != kRCT2DefaultBlockBrakeSpeed)
         {
-            warningMessage = STR_TRACK_DESIGN_BLOCK_BRAKE_SPEED_RESET;
+            version = RCT12::TD46Version::td7;
         }
 
         if (element->HasChain())
-            track.SetFlag(TrackDesignTrackElementFlag::hasChain);
+            track.flags.set(TrackDesignTrackElementFlag::hasChain);
 
-        if (ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasInvertedVariant) && element->IsInverted())
+        if (ride.getRideTypeDescriptor().flags.has(RtdFlag::hasInvertedVariant) && element->IsInverted())
         {
-            track.SetFlag(TrackDesignTrackElementFlag::isInverted);
+            track.flags.set(TrackDesignTrackElementFlag::isInverted);
         }
 
         trackElements.push_back(track);
@@ -273,7 +272,7 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
 
         if (trackElements.size() > RCT2::Limits::kTD6MaxTrackElements)
         {
-            return { false, STR_TRACK_TOO_LARGE_OR_TOO_MUCH_SCENERY };
+            version = RCT12::TD46Version::td7;
         }
     } while (trackElement.element != initialMap);
 
@@ -354,7 +353,7 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
     gMapSelectFlags.unset(MapSelectFlag::green);
 
     statistics.spaceRequired = TileCoordsXY(tds.previewMax - tds.previewMin) + TileCoordsXY{ 1, 1 };
-    return { true, warningMessage };
+    return { true, kStringIdNone };
 }
 
 ResultWithMessage TrackDesign::CreateTrackDesignMaze(TrackDesignState& tds, const Ride& ride)
@@ -393,9 +392,9 @@ ResultWithMessage TrackDesign::CreateTrackDesignMaze(TrackDesignState& tds, cons
                 _saveDirection = tileElement->GetDirection();
                 mazeElements.push_back(maze);
 
-                if (mazeElements.size() >= 2000)
+                if (mazeElements.size() >= RCT2::Limits::kTD6MaxMazeElements)
                 {
-                    return { false, STR_TRACK_TOO_LARGE_OR_TOO_MUCH_SCENERY };
+                    version = RCT12::TD46Version::td7;
                 }
             } while (!(tileElement++)->IsLastForTile());
         }
@@ -500,6 +499,9 @@ CoordsXYE TrackDesign::MazeGetFirstElement(const Ride& ride)
 ResultWithMessage TrackDesign::CreateTrackDesignScenery(TrackDesignState& tds)
 {
     sceneryElements = _trackSavedTileElementsDesc;
+    if (sceneryElements.size() >= RCT2::Limits::kTD6MaxSceneryElements)
+        version = RCT12::TD46Version::td7;
+
     // Run an element loop
     for (auto& scenery : sceneryElements)
     {
@@ -623,7 +625,7 @@ std::unique_ptr<TrackDesign> TrackDesignImport(const utf8* path)
  */
 static void TrackDesignLoadSceneryObjects(const TrackDesign& td)
 {
-    auto& objectManager = OpenRCT2::GetContext()->GetObjectManager();
+    auto& objectManager = GetContext()->GetObjectManager();
     objectManager.UnloadAllTransient();
 
     // Load ride object
@@ -689,7 +691,7 @@ static std::optional<TrackSceneryEntry> TrackDesignPlaceSceneryElementGetEntry(c
 {
     TrackSceneryEntry result;
 
-    auto& objectMgr = OpenRCT2::GetContext()->GetObjectManager();
+    auto& objectMgr = GetContext()->GetObjectManager();
     if (scenery.sceneryObject.GetType() == ObjectType::paths)
     {
         auto footpathMapping = RCT2::GetFootpathSurfaceId(scenery.sceneryObject, true, scenery.isQueue());
@@ -754,7 +756,7 @@ static std::optional<TrackSceneryEntry> TrackDesignPlaceSceneryElementGetEntry(c
  */
 static void TrackDesignMirrorScenery(TrackDesign& td)
 {
-    auto& objectMgr = OpenRCT2::GetContext()->GetObjectManager();
+    auto& objectMgr = GetContext()->GetObjectManager();
     for (auto& scenery : td.sceneryElements)
     {
         auto entryInfo = TrackDesignPlaceSceneryElementGetEntry(scenery);
@@ -1406,7 +1408,7 @@ static std::optional<GameActions::Result> TrackDesignPlaceEntrances(
                 }
                 else
                 {
-                    auto res = GameActions::RideEntranceExitPlaceAction::TrackPlaceQuery(newCoords, false);
+                    auto res = GameActions::RideEntranceExitPlaceAction::TrackPlaceQuery(gameState, newCoords, false);
                     if (res.error != GameActions::Status::ok)
                     {
                         return res;
@@ -1613,11 +1615,11 @@ static GameActions::Result TrackDesignPlaceRide(
                 int16_t tempZ = newCoords.z - trackCoordinates->zBegin;
 
                 SelectedLiftAndInverted liftHillAndAlternativeState{};
-                if (track.HasFlag(TrackDesignTrackElementFlag::hasChain))
+                if (track.flags.has(TrackDesignTrackElementFlag::hasChain))
                 {
                     liftHillAndAlternativeState.set(LiftHillAndInverted::liftHill);
                 }
-                if (track.HasFlag(TrackDesignTrackElementFlag::isInverted))
+                if (track.flags.has(TrackDesignTrackElementFlag::isInverted))
                 {
                     liftHillAndAlternativeState.set(LiftHillAndInverted::inverted);
                 }
@@ -1641,8 +1643,8 @@ static GameActions::Result TrackDesignPlaceRide(
                 }
 
                 auto trackPlaceAction = GameActions::TrackPlaceAction(
-                    ride.id, trackType, ride.type, { newCoords, tempZ, static_cast<uint8_t>(rotation) },
-                    track.brakeBoosterSpeed, track.colourScheme, track.seatRotation, liftHillAndAlternativeState, true);
+                    ride.id, trackType, ride.type, { newCoords, tempZ, rotation }, track.brakeBoosterSpeed, track.colourScheme,
+                    track.seatRotation, liftHillAndAlternativeState, true);
                 trackPlaceAction.SetFlags(flags);
 
                 auto res = flags.has(CommandFlag::apply) ? GameActions::ExecuteNested(&trackPlaceAction, gameState)
@@ -1921,7 +1923,7 @@ static bool TrackDesignPlacePreview(
 
     // Flat rides need their vehicle colours loaded for display
     // in the preview window
-    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).HasFlag(RtdFlag::hasTrack))
+    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).flags.has(RtdFlag::hasTrack))
     {
         for (size_t i = 0; i < std::size(ride->vehicleColours); i++)
         {
@@ -2068,7 +2070,7 @@ bool TrackDesignSceneryElement::operator!=(const TrackDesignSceneryElement& rhs)
  *
  *  rct2: 0x006D1EF0
  */
-void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels, bool placeScenery)
+void TrackDesignDrawPreview(TrackDesign& td, TrackDesignPreviewBuffer& pixels, bool placeScenery)
 {
     StashMap();
     TrackDesignPreviewClearMap();
@@ -2084,7 +2086,7 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels, bool placeScenery)
     TrackDesignGameStateData updatedGameStateData = td.gameStateData;
     if (!TrackDesignPlacePreview(tds, td, &ride, updatedGameStateData, placeScenery))
     {
-        std::fill_n(pixels, kTrackPreviewImageSize * 4, 0x00);
+        std::fill(std::begin(pixels), std::end(pixels), PaletteIndex::transparent);
         UnstashMap();
         return;
     }
@@ -2099,7 +2101,7 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels, bool placeScenery)
 
     // Special case for flat rides - Z-axis info is irrelevant
     // and must be zeroed out lest the preview be off-centre
-    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).HasFlag(RtdFlag::hasTrack))
+    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).flags.has(RtdFlag::hasTrack))
     {
         centre.z = 0;
         size_z = 0;
@@ -2137,7 +2139,7 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels, bool placeScenery)
     rt.width = 370;
     rt.height = 217;
     rt.pitch = 0;
-    rt.bits = pixels;
+    rt.bits = pixels.data();
 
     auto drawingEngine = std::make_unique<X8DrawingEngine>(GetContext()->GetUiContext());
     rt.DrawingEngine = drawingEngine.get();
@@ -2145,10 +2147,10 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels, bool placeScenery)
     drawingEngine->BeginDraw();
 
     const ScreenCoordsXY offset = { size_x / 2, size_y / 2 };
-    for (uint8_t i = 0; i < 4; i++)
+    for (Direction direction = 0; direction < kNumOrthogonalDirections; direction++)
     {
-        view.viewPos = Translate3DTo2DWithZ(i, centre) - offset;
-        view.rotation = i;
+        view.viewPos = Translate3DTo2DWithZ(direction, centre) - offset;
+        view.rotation = direction;
         ViewportRender(rt, &view);
 
         rt.bits += kTrackPreviewImageSize;
@@ -2211,3 +2213,21 @@ void TrackDesignGameStateData::setFlag(TrackDesignGameStateFlag flag, bool on)
     else
         flags &= ~EnumToFlag(flag);
 }
+
+u8string trackDesignGetExtension(RCT12::TD46Version version)
+{
+    switch (version)
+    {
+        case RCT12::TD46Version::td4:
+        case RCT12::TD46Version::td4AA:
+            return ".td4";
+        case RCT12::TD46Version::td6:
+            return ".td6";
+        case RCT12::TD46Version::td7:
+            return ".td7";
+        case RCT12::TD46Version::unknown:
+            break;
+    }
+
+    return "";
+}
