@@ -23,6 +23,7 @@
 #include "../paint/support/MetalSupports.h"
 #include "../paint/support/WoodenSupports.h"
 #include "../paint/tile_element/Paint.TileElement.h"
+#include "../paint/tile_element/Paint.Track.h"
 #include "../paint/tile_element/Segment.h"
 #include "../paint/track/Segment.h"
 #include "../paint/track/Support.h"
@@ -84,17 +85,6 @@ static constexpr uint32_t trackSpritesGhostTrainSpinningTunnel[2][2][4] = {
     },
 };
 
-enum
-{
-    SPR_STATION_COVER_OFFSET_NE_SW_BACK_0 = 0,
-    SPR_STATION_COVER_OFFSET_NE_SW_BACK_1,
-    SPR_STATION_COVER_OFFSET_NE_SW_FRONT,
-    SPR_STATION_COVER_OFFSET_SE_NW_BACK_0,
-    SPR_STATION_COVER_OFFSET_SE_NW_BACK_1,
-    SPR_STATION_COVER_OFFSET_SE_NW_FRONT,
-    SPR_STATION_COVER_OFFSET_TALL
-};
-
 bool TrackPaintUtilHasFence(
     enum edge_t edge, const CoordsXY& position, const TrackElement& trackElement, const Ride& ride, uint8_t rotation)
 {
@@ -669,8 +659,8 @@ bool TrackPaintUtilDrawStationCovers2(
         return false;
     }
 
-    auto baseImageIndex = stationObject->ShelterImageId;
-    if (baseImageIndex == kImageIndexUndefined)
+    auto shelterImageIndex = stationObject->shelterIndex;
+    if (shelterImageIndex == kImageIndexUndefined)
         return false;
 
     static constexpr int16_t heights[][2] = {
@@ -707,10 +697,10 @@ bool TrackPaintUtilDrawStationCovers2(
         imageOffset += SPR_STATION_COVER_OFFSET_TALL;
     }
 
-    auto imageId = session.TrackColours.WithIndex(baseImageIndex + imageOffset);
+    auto imageId = session.TrackColours.WithIndex(shelterImageIndex + imageOffset);
     if (!session.TrackColours.IsRemap())
     {
-        imageId = ImageId(baseImageIndex + imageOffset);
+        imageId = ImageId(shelterImageIndex + imageOffset);
         if (stationObject->Flags & StationObjectFlags::hasPrimaryColour)
             imageId = imageId.WithPrimary(session.TrackColours.GetPrimary());
         if (stationObject->Flags & StationObjectFlags::hasSecondaryColour)
@@ -722,7 +712,8 @@ bool TrackPaintUtilDrawStationCovers2(
     // Glass
     if (colour == TrackStationColour && (stationObject->Flags & StationObjectFlags::isTransparent))
     {
-        imageId = ImageId(baseImageIndex + imageOffset + 12).WithTransparency(session.TrackColours.GetPrimary());
+        auto shelterGlassImageIndex = stationObject->shelterGlassIndex;
+        imageId = ImageId(shelterGlassImageIndex + imageOffset).WithTransparency(session.TrackColours.GetPrimary());
         PaintAddImageAsChild(session, imageId, offset, boundBox);
     }
     return true;
@@ -736,6 +727,7 @@ bool TrackPaintUtilDrawNarrowStationPlatform(
     const auto* stationObj = ride.getStationObject();
     if (stationObj != nullptr && stationObj->Flags & StationObjectFlags::noPlatforms)
         return false;
+
     auto colour = GetStationColourScheme(session, trackElement);
     if (direction & 1)
     {
@@ -2011,7 +2003,7 @@ void PaintTrack(PaintSession& session, Direction direction, int32_t height, cons
             const auto* originElement = ride->getOriginElement(StationIndex::FromUnderlying(0));
             if (originElement != nullptr && originElement->GetTrackType() == TrackElemType::flatTrack1x1B)
                 LightFx::AddKioskLights(session.MapPosition, height, zOffset);
-            else if (kRideTypeDescriptors[ride->type].HasFlag(RtdFlag::isShopOrFacility))
+            else if (kRideTypeDescriptors[ride->type].flags.has(RtdFlag::isShopOrFacility))
                 LightFx::AddShopLights(session.MapPosition, trackElement.GetDirection(), height, zOffset);
         }
 
@@ -2033,7 +2025,7 @@ void PaintTrack(PaintSession& session, Direction direction, int32_t height, cons
         }
 
         const auto& rtd = GetRideTypeDescriptor(trackElement.GetRideType());
-        bool isInverted = trackElement.IsInverted() && rtd.HasFlag(RtdFlag::hasInvertedVariant);
+        bool isInverted = trackElement.IsInverted() && rtd.flags.has(RtdFlag::hasInvertedVariant);
         const auto trackDrawerEntry = getTrackDrawerEntry(rtd, isInverted, TrackElementIsCovered(trackType));
 
         trackType = UncoverTrackElement(trackType);
