@@ -12,13 +12,13 @@
     #include "ScriptEngine.h"
 
     #include "../PlatformEnvironment.h"
-    #include "../actions/BannerPlaceAction.h"
-    #include "../actions/CustomAction.h"
-    #include "../actions/GameAction.h"
-    #include "../actions/LargeSceneryPlaceAction.h"
-    #include "../actions/RideCreateAction.h"
-    #include "../actions/StaffHireNewAction.h"
-    #include "../actions/WallPlaceAction.h"
+    #include "../actions/GameAction.hpp"
+    #include "../actions/general/CustomAction.h"
+    #include "../actions/peep/StaffHireNewAction.h"
+    #include "../actions/ride/RideCreateAction.h"
+    #include "../actions/scenery/BannerPlaceAction.h"
+    #include "../actions/scenery/LargeSceneryPlaceAction.h"
+    #include "../actions/scenery/WallPlaceAction.h"
     #include "../config/Config.h"
     #include "../core/EnumMap.hpp"
     #include "../core/File.h"
@@ -959,7 +959,7 @@ void ScriptEngine::CheckAndStartPlugins()
 
 void ScriptEngine::ProcessREPL()
 {
-    while (_evalQueue.size() > 0)
+    while (!_evalQueue.empty())
     {
         auto item = std::move(_evalQueue.front());
         _evalQueue.pop();
