@@ -11,7 +11,7 @@
 
 #ifdef ENABLE_SCRIPTING
 
-    #include "../actions/CustomAction.h"
+    #include "../actions/general/CustomAction.h"
     #include "../core/FileWatcher.h"
     #include "../management/Finance.h"
     #include "../world/Location.hpp"
