@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -23,37 +23,37 @@ namespace OpenRCT2::Scripting
 {
     static const DukEnumMap<Vehicle::Status> VehicleStatusMap(
         {
-            { "moving_to_end_of_station", Vehicle::Status::MovingToEndOfStation },
-            { "waiting_for_passengers", Vehicle::Status::WaitingForPassengers },
-            { "waiting_to_depart", Vehicle::Status::WaitingToDepart },
-            { "departing", Vehicle::Status::Departing },
-            { "travelling", Vehicle::Status::Travelling },
-            { "arriving", Vehicle::Status::Arriving },
-            { "unloading_passengers", Vehicle::Status::UnloadingPassengers },
-            { "travelling_boat", Vehicle::Status::TravellingBoat },
-            { "crashing", Vehicle::Status::Crashing },
-            { "crashed", Vehicle::Status::Crashed },
-            { "travelling_dodgems", Vehicle::Status::TravellingDodgems },
-            { "swinging", Vehicle::Status::Swinging },
-            { "rotating", Vehicle::Status::Rotating },
-            { "ferris_wheel_rotating", Vehicle::Status::FerrisWheelRotating },
-            { "simulator_operating", Vehicle::Status::SimulatorOperating },
-            { "showing_film", Vehicle::Status::ShowingFilm },
-            { "space_rings_operating", Vehicle::Status::SpaceRingsOperating },
-            { "top_spin_operating", Vehicle::Status::TopSpinOperating },
-            { "haunted_house_operating", Vehicle::Status::HauntedHouseOperating },
-            { "doing_circus_show", Vehicle::Status::DoingCircusShow },
-            { "crooked_house_operating", Vehicle::Status::CrookedHouseOperating },
-            { "waiting_for_cable_lift", Vehicle::Status::WaitingForCableLift },
-            { "travelling_cable_lift", Vehicle::Status::TravellingCableLift },
-            { "stopping", Vehicle::Status::Stopping },
-            { "waiting_for_passengers_17", Vehicle::Status::WaitingForPassengers17 },
-            { "waiting_to_start", Vehicle::Status::WaitingToStart },
-            { "starting", Vehicle::Status::Starting },
-            { "operating_1a", Vehicle::Status::Operating1A },
-            { "stopping_1b", Vehicle::Status::Stopping1B },
-            { "unloading_passengers_1c", Vehicle::Status::UnloadingPassengers1C },
-            { "stopped_by_block_brake", Vehicle::Status::StoppedByBlockBrakes },
+            { "moving_to_end_of_station", Vehicle::Status::movingToEndOfStation },
+            { "waiting_for_passengers", Vehicle::Status::waitingForPassengers },
+            { "waiting_to_depart", Vehicle::Status::waitingToDepart },
+            { "departing", Vehicle::Status::departing },
+            { "travelling", Vehicle::Status::travelling },
+            { "arriving", Vehicle::Status::arriving },
+            { "unloading_passengers", Vehicle::Status::unloadingPassengers },
+            { "travelling_boat", Vehicle::Status::travellingBoat },
+            { "crashing", Vehicle::Status::crashing },
+            { "crashed", Vehicle::Status::crashed },
+            { "travelling_dodgems", Vehicle::Status::travellingDodgems },
+            { "swinging", Vehicle::Status::swinging },
+            { "rotating", Vehicle::Status::rotating },
+            { "ferris_wheel_rotating", Vehicle::Status::ferrisWheelRotating },
+            { "simulator_operating", Vehicle::Status::simulatorOperating },
+            { "showing_film", Vehicle::Status::showingFilm },
+            { "space_rings_operating", Vehicle::Status::spaceRingsOperating },
+            { "top_spin_operating", Vehicle::Status::topSpinOperating },
+            { "haunted_house_operating", Vehicle::Status::hauntedHouseOperating },
+            { "doing_circus_show", Vehicle::Status::doingCircusShow },
+            { "crooked_house_operating", Vehicle::Status::crookedHouseOperating },
+            { "waiting_for_cable_lift", Vehicle::Status::waitingForCableLift },
+            { "travelling_cable_lift", Vehicle::Status::travellingCableLift },
+            { "stopping", Vehicle::Status::stopping },
+            { "waiting_for_passengers_17", Vehicle::Status::waitingForPassengers17 },
+            { "waiting_to_start", Vehicle::Status::waitingToStart },
+            { "starting", Vehicle::Status::starting },
+            { "operating_1a", Vehicle::Status::operating1A },
+            { "stopping_1b", Vehicle::Status::stopping1B },
+            { "unloading_passengers_1c", Vehicle::Status::unloadingPassengers1C },
+            { "stopped_by_block_brake", Vehicle::Status::stoppedByBlockBrakes },
         });
 
     ScVehicle::ScVehicle(EntityId id)
@@ -79,10 +79,10 @@ namespace OpenRCT2::Scripting
         dukglue_register_property(ctx, &ScVehicle::velocity_get, &ScVehicle::velocity_set, "velocity");
         dukglue_register_property(ctx, &ScVehicle::bankRotation_get, &ScVehicle::bankRotation_set, "bankRotation");
         dukglue_register_property(
-            ctx, &ScVehicle::flag_get<VehicleFlags::CarIsReversed>, &ScVehicle::flag_set<VehicleFlags::CarIsReversed>,
+            ctx, &ScVehicle::flag_get<VehicleFlag::carIsReversed>, &ScVehicle::flag_set<VehicleFlag::carIsReversed>,
             "isReversed");
         dukglue_register_property(
-            ctx, &ScVehicle::flag_get<VehicleFlags::Crashed>, &ScVehicle::flag_set<VehicleFlags::Crashed>, "isCrashed");
+            ctx, &ScVehicle::flag_get<VehicleFlag::crashed>, &ScVehicle::flag_set<VehicleFlag::crashed>, "isCrashed");
         dukglue_register_property(ctx, &ScVehicle::colours_get, &ScVehicle::colours_set, "colours");
         dukglue_register_property(ctx, &ScVehicle::trackLocation_get, nullptr, "trackLocation");
         dukglue_register_property(ctx, &ScVehicle::trackProgress_get, nullptr, "trackProgress");
@@ -102,7 +102,7 @@ namespace OpenRCT2::Scripting
 
     Vehicle* ScVehicle::GetVehicle() const
     {
-        return ::getGameState().entities.GetEntity<Vehicle>(_id);
+        return getGameState().entities.GetEntity<Vehicle>(_id);
     }
 
     ObjectEntryIndex ScVehicle::rideObject_get() const
@@ -350,14 +350,14 @@ namespace OpenRCT2::Scripting
         }
     }
 
-    template<uint32_t flag>
+    template<VehicleFlag flag>
     bool ScVehicle::flag_get() const
     {
         auto vehicle = GetVehicle();
-        return vehicle != nullptr ? vehicle->HasFlag(flag) : false;
+        return vehicle != nullptr ? vehicle->flags.has(static_cast<VehicleFlag>(flag)) : false;
     }
 
-    template<uint32_t flag>
+    template<VehicleFlag flag>
     void ScVehicle::flag_set(bool value)
     {
         ThrowIfGameStateNotMutable();
@@ -366,11 +366,11 @@ namespace OpenRCT2::Scripting
         {
             if (value)
             {
-                vehicle->SetFlag(flag);
+                vehicle->flags.set(static_cast<VehicleFlag>(flag));
             }
             else
             {
-                vehicle->ClearFlag(flag);
+                vehicle->flags.unset(static_cast<VehicleFlag>(flag));
             }
             vehicle->Invalidate();
         }
