@@ -11,8 +11,9 @@
 
 #ifdef ENABLE_SCRIPTING
 
+    #include "../../../Game.h"
     #include "../../../OpenRCT2.h"
-    #include "../../../actions/GameAction.h"
+    #include "../../../actions/GameActionRunner.h"
     #include "../../../interface/Screenshot.h"
     #include "../../../localisation/Formatting.h"
     #include "../../../object/ObjectManager.h"
