@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -12,8 +12,10 @@
     #include "ScNetwork.hpp"
 
     #include "../../../Context.h"
-    #include "../../../actions/NetworkModifyGroupAction.h"
-    #include "../../../actions/PlayerKickAction.h"
+    #include "../../../GameState.h"
+    #include "../../../actions/GameActionRunner.h"
+    #include "../../../actions/network/NetworkModifyGroupAction.h"
+    #include "../../../actions/network/PlayerKickAction.h"
     #include "../../../network/Network.h"
     #include "../../../network/NetworkAction.h"
 
@@ -27,12 +29,14 @@ namespace OpenRCT2::Scripting
     std::string ScNetwork::mode_get() const
     {
     #ifndef DISABLE_NETWORK
-        switch (NetworkGetMode())
+        switch (Network::GetMode())
         {
-            case NETWORK_MODE_SERVER:
+            case Network::Mode::server:
                 return "server";
-            case NETWORK_MODE_CLIENT:
+            case Network::Mode::client:
                 return "client";
+            default:
+                break;
         }
     #endif
         return "none";
@@ -41,7 +45,7 @@ namespace OpenRCT2::Scripting
     int32_t ScNetwork::numPlayers_get() const
     {
     #ifndef DISABLE_NETWORK
-        return NetworkGetNumPlayers();
+        return Network::GetNumPlayers();
     #else
         return 0;
     #endif
@@ -50,7 +54,7 @@ namespace OpenRCT2::Scripting
     int32_t ScNetwork::numGroups_get() const
     {
     #ifndef DISABLE_NETWORK
-        return NetworkGetNumGroups();
+        return Network::GetNumGroups();
     #else
         return 0;
     #endif
@@ -59,7 +63,7 @@ namespace OpenRCT2::Scripting
     int32_t ScNetwork::defaultGroup_get() const
     {
     #ifndef DISABLE_NETWORK
-        return NetworkGetDefaultGroup();
+        return Network::GetDefaultGroup();
     #else
         return 0;
     #endif
@@ -69,7 +73,7 @@ namespace OpenRCT2::Scripting
     {
     #ifndef DISABLE_NETWORK
         auto action = GameActions::NetworkModifyGroupAction(GameActions::ModifyGroupType::SetDefault, value);
-        GameActions::Execute(&action);
+        GameActions::Execute(&action, getGameState());
     #endif
     }
 
@@ -77,10 +81,10 @@ namespace OpenRCT2::Scripting
     {
         std::vector<std::shared_ptr<ScPlayerGroup>> groups;
     #ifndef DISABLE_NETWORK
-        auto numGroups = NetworkGetNumGroups();
+        auto numGroups = Network::GetNumGroups();
         for (int32_t i = 0; i < numGroups; i++)
         {
-            auto groupId = NetworkGetGroupID(i);
+            auto groupId = Network::GetGroupID(i);
             groups.push_back(std::make_shared<ScPlayerGroup>(groupId));
         }
     #endif
@@ -91,10 +95,10 @@ namespace OpenRCT2::Scripting
     {
         std::vector<std::shared_ptr<ScPlayer>> players;
     #ifndef DISABLE_NETWORK
-        auto numPlayers = NetworkGetNumPlayers();
+        auto numPlayers = Network::GetNumPlayers();
         for (int32_t i = 0; i < numPlayers; i++)
         {
-            auto playerId = NetworkGetPlayerID(i);
+            auto playerId = Network::GetPlayerID(i);
             players.push_back(std::make_shared<ScPlayer>(playerId));
         }
     #endif
@@ -105,7 +109,7 @@ namespace OpenRCT2::Scripting
     {
         std::shared_ptr<ScPlayer> player;
     #ifndef DISABLE_NETWORK
-        auto playerId = NetworkGetCurrentPlayerId();
+        auto playerId = Network::GetCurrentPlayerId();
         player = std::make_shared<ScPlayer>(playerId);
     #endif
         return player;
@@ -117,16 +121,16 @@ namespace OpenRCT2::Scripting
         if (GetTargetAPIVersion() < kApiVersionNetworkIDs)
         {
             auto index = id;
-            auto numPlayers = NetworkGetNumPlayers();
+            auto numPlayers = Network::GetNumPlayers();
             if (index < numPlayers)
             {
-                auto playerId = NetworkGetPlayerID(index);
+                auto playerId = Network::GetPlayerID(index);
                 return std::make_shared<ScPlayer>(playerId);
             }
         }
         else
         {
-            auto index = NetworkGetPlayerIndex(id);
+            auto index = Network::GetPlayerIndex(id);
             if (index != -1)
             {
                 return std::make_shared<ScPlayer>(id);
@@ -140,8 +144,8 @@ namespace OpenRCT2::Scripting
     DukValue ScNetwork::stats_get() const
     {
     #ifndef DISABLE_NETWORK
-        auto obj = OpenRCT2::Scripting::DukObject(_context);
-        auto networkStats = NetworkGetStats();
+        auto obj = DukObject(_context);
+        auto networkStats = Network::GetStats();
         {
             duk_push_array(_context);
             duk_uarridx_t index = 0;
@@ -176,16 +180,16 @@ namespace OpenRCT2::Scripting
         if (GetTargetAPIVersion() < kApiVersionNetworkIDs)
         {
             auto index = id;
-            auto numGroups = NetworkGetNumGroups();
+            auto numGroups = Network::GetNumGroups();
             if (index < numGroups)
             {
-                auto groupId = NetworkGetGroupID(index);
+                auto groupId = Network::GetGroupID(index);
                 return std::make_shared<ScPlayerGroup>(groupId);
             }
         }
         else
         {
-            auto index = NetworkGetGroupIndex(id);
+            auto index = Network::GetGroupIndex(id);
             if (index != -1)
             {
                 return std::make_shared<ScPlayerGroup>(id);
@@ -199,7 +203,7 @@ namespace OpenRCT2::Scripting
     {
     #ifndef DISABLE_NETWORK
         auto networkModifyGroup = GameActions::NetworkModifyGroupAction(GameActions::ModifyGroupType::AddGroup);
-        GameActions::Execute(&networkModifyGroup);
+        GameActions::Execute(&networkModifyGroup, getGameState());
     #endif
     }
 
@@ -209,21 +213,21 @@ namespace OpenRCT2::Scripting
         if (GetTargetAPIVersion() < kApiVersionNetworkIDs)
         {
             auto index = id;
-            auto numGroups = NetworkGetNumGroups();
+            auto numGroups = Network::GetNumGroups();
             if (index < numGroups)
             {
-                auto groupId = NetworkGetGroupID(index);
+                auto groupId = Network::GetGroupID(index);
                 auto networkAction = GameActions::NetworkModifyGroupAction(GameActions::ModifyGroupType::RemoveGroup, groupId);
-                GameActions::Execute(&networkAction);
+                GameActions::Execute(&networkAction, getGameState());
             }
         }
         else
         {
-            auto index = NetworkGetGroupIndex(id);
+            auto index = Network::GetGroupIndex(id);
             if (index != -1)
             {
                 auto networkAction = GameActions::NetworkModifyGroupAction(GameActions::ModifyGroupType::RemoveGroup, id);
-                GameActions::Execute(&networkAction);
+                GameActions::Execute(&networkAction, getGameState());
             }
         }
     #endif
@@ -235,21 +239,21 @@ namespace OpenRCT2::Scripting
         if (GetTargetAPIVersion() < kApiVersionNetworkIDs)
         {
             auto index = id;
-            auto numPlayers = NetworkGetNumPlayers();
+            auto numPlayers = Network::GetNumPlayers();
             if (index < numPlayers)
             {
-                auto playerId = NetworkGetPlayerID(index);
+                auto playerId = Network::GetPlayerID(index);
                 auto kickPlayerAction = GameActions::PlayerKickAction(playerId);
-                GameActions::Execute(&kickPlayerAction);
+                GameActions::Execute(&kickPlayerAction, getGameState());
             }
         }
         else
         {
-            auto index = NetworkGetPlayerIndex(id);
+            auto index = Network::GetPlayerIndex(id);
             if (index != -1)
             {
                 auto kickPlayerAction = GameActions::PlayerKickAction(id);
-                GameActions::Execute(&kickPlayerAction);
+                GameActions::Execute(&kickPlayerAction, getGameState());
             }
         }
     #endif
@@ -260,7 +264,7 @@ namespace OpenRCT2::Scripting
     #ifndef DISABLE_NETWORK
         if (players.is_array())
         {
-            if (NetworkGetMode() == NETWORK_MODE_SERVER)
+            if (Network::GetMode() == Network::Mode::server)
             {
                 std::vector<uint8_t> playerIds;
                 auto playerArray = players.as_array();
@@ -273,7 +277,7 @@ namespace OpenRCT2::Scripting
                 }
                 if (!playerArray.empty())
                 {
-                    NetworkSendChat(message.c_str(), playerIds);
+                    Network::SendChat(message.c_str(), playerIds);
                 }
             }
             else
@@ -283,7 +287,7 @@ namespace OpenRCT2::Scripting
         }
         else
         {
-            NetworkSendChat(message.c_str());
+            Network::SendChat(message.c_str());
         }
     #endif
     }
